package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut



__DATA__
M?T5,1@(!`0D```````````(`/@`!````@!]```````!``````````""\````
M`````````$``.``'`$``&@`9``8````%````0`````````!``$```````$``
M0```````B`$```````"(`0````````@``````````P````0```#(`0``````
M`,@!0```````R`%````````5`````````!4``````````0`````````!````
M!0````````````````!``````````$```````.BQ````````Z+$`````````
M`!````````$````&````Z+$```````#HL5```````.BQ4```````\`<`````
M````#0``````````$````````@````8```#@M0```````."U4```````X+50
M``````#@`0```````.`!````````"``````````$````!````.`!````````
MX`%```````#@`4```````!@`````````&``````````$`````````%#E=&0$
M````X+$```````#@L4```````."Q0```````"``````````(``````````0`
M````````+VQI8F5X96,O;&0M96QF+G-O+C$`````"`````0````!````1G)E
M94)31`!K-0P`80```&@`````````.P`````````)`````````%T```!<````
M6```````````````90````````!%````6P`````````V````/P```#D````.
M````-0```$H````^````1@```````````````````"````!9````+0````(`
M````````,````%(````K````80```$@````&````9P```&(````:````````
M`"D`````````8``````````L````7P````````!,````)P````4```!/````
M9````#T```!!````)````%4````7````9@`````````O````'P````````!)
M`````````````````````````%$```!$````,P```%<```!>````'0``````
M`````````````%8````Q````0````%0```!:````#0`````````/````!```
M`````````````````#<`````````'@```!,`````````*@```&,`````````
M````````````````````````````````````````````````````````````
M``````````P`````````````````````````````````````````````````
M`````````````!$````#````&`````@```````````````L`````````````
M`````````````0`````````````````````````H`````````!P`````````
M"@```"$`````````(P``````````````````````````````````````````
M`````````#0````````````````````\````````````````````$```````
M```X```````````````B`````````!L````'````)@````````!"````)0``
M`````````````````#H```!.````+@``````````````,@```!8```!-````
M0P`````````2`````````!4```!3````4```````````````2P```!0`````
M````1P```!D`````````````````````````````````````````N`,``!$`
M$``(LE````````@`````````#````!(```#$&T```````(T`````````%P``
M`!(```#4&T```````+H'````````*0```!$`%P#@N5````````$`````````
M7@,``!(```#D&T````````\`````````S`,``!(`#``0/D```````+X!````
M````0````!$`\?_@M5``````````````````P@(``!(```#T&T``````````
M````````W`(``!(````$'$```````#0`````````%0,``!(````4'$``````
M`%4`````````20```!(````D'$```````)$#````````5P```!(````T'$``
M`````+H`````````8P```!(```!$'$````````\!````````V0,``!(`#```
M3T````````4`````````=````!$`%P#HN5````````@`````````8@(``!$`
M%P#PN5```````$``````````?@```!(```!4'$```````!L'````````C0``
M`!$`%P`PNE````````@`````````Z@,``!(`#``0.$```````$T`````````
MEP```!(```!D'$```````.0!````````^`,``!(`#```0$```````.(`````
M````(P,``!(```!T'$````````(`````````\P(``!(```"$'$```````/4,
M````````I0```!$`%P`XNE````````$`````````*00``!(`"@"@&T``````
M````````````L@```!(```"4'$```````/@$````````O0```!(```"D'$``
M`````)``````````R@```!(```"T'$```````&$!````````V````!$`%P#@
MOE````````@`````````X````!(```#$'$```````'8"````````Y`(``!(`
M``#4'$```````$P`````````[`(``!(```#D'$``````````````````!`0`
M`!(`#`!00T```````*P!````````ZP```!(```#T'$```````&<`````````
M$00``!(`#``03T```````,@"````````)P0``!(`#`#@44```````!0`````
M````#@,``!(````$'4````````P`````````MP(``!$`$`#HL5````````@`
M````````A@,``!(`#`"`'T```````)P`````````2P,``!(````4'4``````
M````````````PP(``!(````D'4``````````````````+0,``!(````T'4``
M``````H`````````'`,``!(```!$'4```````%0`````````+P0``!(`#```
M14```````"@)````````^@```!(```!4'4````````0$````````D@(``!(`
M``!D'4``````````````````SP(``!(```!T'4````````@`````````H`(`
M`!(```"$'4```````&<`````````/`0``!(`#`#P0$```````&T`````````
MR`(``!(```"4'4```````'P``````````P$``!$`%P`YNE````````$`````
M````-0,``!(```"D'4```````'X`````````$0$``!(```"T'4```````/X"
M````````(0$``!$`%P!`NE````````@`````````@0,``!``\?_8N5``````
M````````````=`,``!(```#$'4``````````````````2`0``!(`#`!@04``
M`````/`!````````300``!(`#```/4````````T!````````3`(``!$`%P!(
MNE````````0`````````7P0``!(`#``P3D```````,D`````````,0$``!$`
M%P!,NE````````$`````````/`$``!(`#0!84D``````````````````0@$`
M`!(```#4'4```````+H/````````Q`0``!(```#D'4```````!X`````````
M60,``!(```#T'4``````````````````^P(``!$`%P!0NE````````@`````
M````6@(``!(````$'D```````$H`````````4`$``!(````4'D```````$(`
M````````1@,``!(````D'D```````"\`````````;@,``!(````T'D``````
M````````````#`(``!(```!$'D```````#P&````````=00``!$`$``0LE``
M``````@`````````8`$``!(```!4'D```````"L`````````>@,``!``\?_8
MN5``````````````````>P(``!(```!D'D```````$H`````````:P$``!$`
M\?_HMU``````````````````C0,``!``\?_HOE``````````````````F`(`
M`!(```!T'D```````&P`````````@0$``!$`%P!8NE````````$`````````
MC`$``!$`%P!@NE```````!,`````````&`(``!(```"$'D```````&\)````
M````BP(``!(```"4'D``````````````````B00``!(`#`!@.$```````!X`
M````````FP$``!(```"D'D```````'L`````````I@(``!(```"T'D``````
M``P`````````I00``!(`#`"0($```````#0`````````L@$``!$`%P!XNE``
M``````@`````````1`,``!(```#$'D```````"\`````````L@0``!(`#`#0
M/T```````"(`````````N`$``!$`%P"`NE````````@`````````=`(``!(`
M``#4'D``````````````````PP$``!(```#D'D```````'$"````````T0$`
M`!$`%P"(NE````````@`````````4@,``!(```#T'D```````,<`````````
M90,``!(````$'T```````)L`````````UP(``!(````4'T``````````````
M````W@$``"``````````````````````````/`,``!(````D'T```````"T!
M````````\@$``!(````T'T```````!4`````````@@(``!(```!$'T``````
M``````````````(``!(```!4'T```````#8`````````$P(``!(```!D'T``
M`````!4`````````O0,``!$`#@"@54```````.I;`````````&QI8G!E<FPN
M<V\`4&5R;%]C<F]A:P!097)L7W-V7S)P=E]F;&%G<P!03%]P97)L7V1E<W1R
M=6-T7VQE=F5L`%]$64Y!34E#`%!E<FQ?879?<VAI9G0`4&5R;%]M9U]S970`
M4&5R;%]N97=84U]F;&%G<P!03%]C;VUP8W8`<&5R;%]C;VYS=')U8W0`4$Q?
M<&%R<V5R`%!E<FQ?9&]U;G=I;F0`4$Q?9&]?=6YD=6UP`'!E<FQ?<&%R<V4`
M4&5R;%]N97=35G!V`%!E<FQ?<W9?<V5T<'8`96YV:7)O;@!097)L7VYE=UA3
M`%!E<FQ?<WES7VEN:70S`'!E<FQ?<G5N`%!,7V5X:71?9FQA9W,`8F]O=%]$
M>6YA3&]A9&5R`%!,7V-U<G-T86-K:6YF;P!03%]T86EN=&5D`%]F:6YI`'!E
M<FQ?9&5S=')U8W0`4&5R;%]G=E]F971C:'!V`'!E<FQ?86QL;V,`7T=,3T)!
M3%]/1D93151?5$%"3$5?`%!,7VEN7V5V86P`4$Q?;65M;W)Y7W=R87``4&5R
M;%]S879E7V1E<W1R=6-T;W)?>`!03%]O<`!03%]T;W!?96YV`%!E<FQ?879?
M9F5T8V@`4$Q?979A;%]R;V]T`%]*=E]296=I<W1E<D-L87-S97,`4&5R;%]S
M>7-?=&5R;0!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]F<F5E`&QI8FTN<V\N
M-0!L:6)C<GEP="YS;RXU`&QI8G5T:6PN<V\N.`!L:6)C+G-O+C<`7U]M8E]S
M8E]L:6UI=`!M96UM;W9E`%]?<W1A8VM?8VAK7V=U87)D`&=E='!I9`!M96UC
M<'D`<F5A9&QI;FL`9V5T=6ED`')M9&ER`')E861D:7(`;'-E96L`7U]S=&%C
M:U]C:&M?9F%I;`!?7W!R;V=N86UE`&QS=&%T`'-T<G-T<@!?7V5R<F]R`')E
M860`<W1R;F-M<`!S=')N8W!Y`'5N;&EN:P!R96%L;&]C`%]#=7)R96YT4G5N
M94QO8V%L90!S=')T;VL`<W1R9'5P`&UE;7-E=`!?:6YI=%]T;',`;W!E;F1I
M<@!S=')C;7``<W!R:6YT9@!A=&5X:70`86-C97-S`'-T<FQE;@!O<&5N`&5X
M96-V<`!C;&]S961I<@!M:V1I<@!C;&]S90!?961A=&$`7U]B<W-?<W1A<G0`
M7V5N9``O=7-R+VQO8V%L+VQI8B]P97)L-2\U+C$P+C$O;6%C:"]#3U)%`&YA
M;65?;&]A9%]M>5]P87)?<&P`<&%R7VEN:71?96YV`'!A<E]C=7)R96YT7V5X
M96,`<&%R7V5N=E]C;&5A;@!P87)?9&ER;F%M90!P87)?9FEN9'!R;V<`6%-?
M26YT97)N86QS7U!!4E]"3T]4`'AS7VEN:70`<&%R7VUK=&UP9&ER`'!A<E]C
M;&5A;G5P`&UA:6X`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V-U<G)E;G1?97AE
M8U]P<F]C`'-I>F5?;&]A9%]M>5]P87)?<&P`6%-?26YT97)N86QS7U!!4E]#
M3$5!4E-404-+`'!A<E]B87-E;F%M90!G971?=7-E<FYA;65?9G)O;5]G971P
M=W5I9`!&0E-$7S$N,`````$``````````@`!``$``@`"``(``````````0``
M``(```````$````!``(``@````$``````````0````(``@`!`````0`!``(`
M`0`!``(``@`"``(``0````(``@`"``$``@````(```````$``@`!``$``@`!
M`````0````(``@`"``(````"``(``@`!`````0`"``$``0`"```````"``(`
M`0````(``0````(``0````(```````(``@`"`````@````(```````$````!
M``$`0@(``!``````````L"AZ!P```@#-!````````."Y4```````!0````0`
M`````````````.BY4```````!0````\``````````````/"Y4```````!0``
M`!```````````````#"Z4```````!0```!(``````````````#BZ4```````
M!0```!@``````````````#FZ4```````!0```#,``````````````$"Z4```
M````!0```#8``````````````$BZ4```````!0```#L``````````````$RZ
M4```````!0```#T``````````````%"Z4```````!0```$(`````````````
M`%BZ4```````!0```$\``````````````&"Z4```````!0```%``````````
M`````'BZ4```````!0```%<``````````````("Z4```````!0```%H`````
M`````````(BZ4```````!0```%T```````````````"X4```````!P````(`
M``````````````BX4```````!P````,``````````````!"X4```````!P``
M``4``````````````!BX4```````!P````@``````````````""X4```````
M!P````D``````````````"BX4```````!P````H``````````````#"X4```
M````!P````L``````````````#BX4```````!P````P``````````````$"X
M4```````!P````T``````````````$BX4```````!P```!$`````````````
M`%"X4```````!P```!0``````````````%BX4```````!P```!8`````````
M`````&"X4```````!P```!<``````````````&BX4```````!P```!H`````
M`````````'"X4```````!P```!L``````````````'BX4```````!P```!P`
M`````````````("X4```````!P```!X``````````````(BX4```````!P``
M`!\``````````````)"X4```````!P```"```````````````)BX4```````
M!P```"(``````````````*"X4```````!P```"4``````````````*BX4```
M````!P```"@``````````````+"X4```````!P```"D``````````````+BX
M4```````!P```"H``````````````,"X4```````!P```"L`````````````
M`,BX4```````!P```"T``````````````-"X4```````!P```"X`````````
M`````-BX4```````!P```"\``````````````."X4```````!P```#``````
M`````````.BX4```````!P```#(``````````````/"X4```````!P```#0`
M`````````````/BX4```````!P```#4```````````````"Y4```````!P``
M`#@```````````````BY4```````!P```#\``````````````!"Y4```````
M!P```$```````````````!BY4```````!P```$$``````````````""Y4```
M````!P```$,``````````````"BY4```````!P```$0``````````````#"Y
M4```````!P```$4``````````````#BY4```````!P```$8`````````````
M`$"Y4```````!P```$<``````````````$BY4```````!P```$D`````````
M`````%"Y4```````!P```$L``````````````%BY4```````!P```$X`````
M`````````&"Y4```````!P```%$``````````````&BY4```````!P```%(`
M`````````````'"Y4```````!P```%0``````````````'BY4```````!P``
M`%4``````````````("Y4```````!P```%@``````````````(BY4```````
M!P```%L``````````````)"Y4```````!P```%P``````````````)BY4```
M````!P```%X``````````````*"Y4```````!P```%\``````````````*BY
M4```````!P```&```````````````+"Y4```````!P```&(`````````````
M`+BY4```````!P```&,``````````````,"Y4```````!P```&0`````````
M`````,BY4```````!P```&4``````````````-"Y4```````!P```&8`````
M`````````$B#[`CHMP0``.B"-@``2(/$",,`_S4VG!``_R4XG!``D)"0D/\E
M-IP0`&@`````Z>#_____)2Z<$`!H`0```.G0_____R4FG!``:`(```#IP/__
M__\E'IP0`&@#````Z;#_____)1:<$`!H!````.F@_____R4.G!``:`4```#I
MD/____\E!IP0`&@&````Z8#_____)?Z;$`!H!P```.EP_____R7VFQ``:`@`
M``#I8/____\E[IL0`&@)````Z5#_____)>:;$`!H"@```.E`_____R7>FQ``
M:`L```#I,/____\EUIL0`&@,````Z2#_____)<Z;$`!H#0```.D0_____R7&
MFQ``:`X```#I`/____\EOIL0`&@/````Z?#^____);:;$`!H$````.G@_O__
M_R6NFQ``:!$```#IT/[___\EIIL0`&@2````Z<#^____)9Z;$`!H$P```.FP
M_O___R66FQ``:!0```#IH/[___\ECIL0`&@5````Z9#^____)8:;$`!H%@``
M`.F`_O___R5^FQ``:!<```#I</[___\E=IL0`&@8````Z6#^____)6Z;$`!H
M&0```.E0_O___R5FFQ``:!H```#I0/[___\E7IL0`&@;````Z3#^____)5:;
M$`!H'````.D@_O___R5.FQ``:!T```#I$/[___\E1IL0`&@>````Z0#^____
M)3Z;$`!H'P```.GP_?___R4VFQ``:"````#IX/W___\E+IL0`&@A````Z=#]
M____)2:;$`!H(@```.G`_?___R4>FQ``:",```#IL/W___\E%IL0`&@D````
MZ:#]____)0Z;$`!H)0```.F0_?___R4&FQ``:"8```#I@/W___\E_IH0`&@G
M````Z7#]____)?::$`!H*````.E@_?___R7NFA``:"D```#I4/W___\EYIH0
M`&@J````Z4#]____)=Z:$`!H*P```.DP_?___R76FA``:"P```#I(/W___\E
MSIH0`&@M````Z1#]____)<::$`!H+@```.D`_?___R6^FA``:"\```#I\/S_
M__\EMIH0`&@P````Z>#\____):Z:$`!H,0```.G0_/___R6FFA``:#(```#I
MP/S___\EGIH0`&@S````Z;#\____)9::$`!H-````.F@_/___R6.FA``:#4`
M``#ID/S___\EAIH0`&@V````Z8#\____)7Z:$`!H-P```.EP_/___R5VFA``
M:#@```#I8/S___\E;IH0`&@Y````Z5#\____)6::$`!H.@```.E`_/__````
M````````````54B)Y4%53(UO"$%44TB#[`B+'TACPX7;3(UDQQ!,B24\GQ``
M?CI(BU<(2(72=#%(B14RDA``#[8"A,!T(TB#P@$\+TB+!1Z2$`!(#T3"2(D%
M$Y(0``^V`DB#P@&$P'7AN."U4`!(A<!T*TB)]^C2_O__OUA20`#HR/[__^B?
M^___B=],B>),B>[H4B$``(G'Z`_^___H6OS__^O6D)"0D$B#[`B`/66:$```
M=!#K))!(@\`(2(D%O9$0`/_22(L%M)$0`$B+$$B%TG7DQ@4]FA```4B#Q`C#
M9F9FD&9F9I!(@SUXEQ```'06N`````!(A<!T#+_@MU``28G#0?_CD//#D)"0
MD)"0D)"0D)"0D)`/M@](B?B$R70H2(L%/S0``$B-5P$/MC!(B?AF9I!FD$`X
M\0^V"D@/1,)(@\(!A,EU[O/#9F9FD&9F9I!F9F:0059(C7<X055!5%5(B?U3
M2('L"`(``$R-3"2(38V!@````$R)STB+#DB#Q@A(B<I(B<A(P>((2,'@&"4`
M``#_@>(``/\`2`G"2(G(2,'H""4`_P``2`G"2(G(2,'H&"7_````2`G"2(G(
M2,'I*$C!Z"!(B1=(P>`(2(G"2,'@$"4```#_@>(``/\`2`G"2(G(2,'I$"4`
M_P``2`G"2`G*2(E7"$B#QQ!,.<</A77___])C4EH28VQ:`(``&9FD&:02(L!
M2#-!V$@S0:A(,T&82(G"2`'`2,'J'T@)PH/B_TB)41A(@\$(2#GQ==1,BW4`
M2(M\)(A!O=R\&X](`WT@2(M-"$R+51!(BW483(GP3(GR38GQ2,'B!4C!Z!M)
MB<A("=!,B=))P>@"@^#_2"'*2<'I`DB-O`>9>8):2(G(2,'A'DCWT$D)R$@A
M\$&#X/](`W0DD$@)T$R)P@''3(GP3"'R2/?02(GY3"'02,'I&TP#5"282`G"
M2(GX2,'@!4B-M!:9>8):2(GZ2`G!3(GP2,'@'@'Q20G!2(GX2(G.08/A_TCW
MT$C![AM,(<I,(<!("=!(B<I-C90"F7F"6DB)R$C!X`5("<9(B<A$`=9)B?I(
M]]!)P>H"2,'G'DP#1"2@20GZ3"'(2(GW08/B_TC![QM,`TPDJ$PATD@)T$B)
M\DV-A`"9>8):2(GP2,'@!4@)QTB)\$0!QTF)R$C!X1Y)P>@"2/?020G(3"'0
M2(GY08/@_TC!Z1M,`U0DL$PAPD@)T$B)^DV-C`&9>8):2(GX2,'@!4@)P4B)
M^$0!R4F)\4C!YAY)P>D"2/?020GQ3"'`2(G.08/A_TC![AM,(<I("=!(B<I-
MC90"F7F"6DB)R$C!X`5,`T0DN$@)QDB)R$0!UDF)^DC!YQY)P>H"2/?020GZ
M3"'(2(GW08/B_TC![QM,`TPDP$PATD@)T$B)\DV-A`"9>8):2(GP2,'@!4@)
MQTB)\$0!QTF)R$C!X1Y)P>@"2/?020G(3"'02(GY08/@_TC!Z1M,`U0DR$PA
MPD@)T$B)^DV-C`&9>8):2(GX2,'@!4@)P4B)^$0!R4F)\4C!YAY)P>D"2/?0
M20GQ3"'`2(G.08/A_TPARDC![AM,`T0DT$@)T$B)RDV-E`*9>8):2(G(2,'@
M!4@)QDB)R$0!UDF)^DC!YQY)P>H"2/?020GZ3"'(2(GW08/B_TC![QM,`TPD
MV$PATD@)T$B)\DV-A`"9>8):2(GP2,'@!4@)QTB)\$0!QTF)R$C!X1Y)P>@"
M2/?020G(3"'02(GY08/@_TC!Z1M,(<)("=!(B?I-C8P!F7F"6DB)^$C!X`5(
M"<%(B?A$`<E)B?%(P>8>2<'I`DCWT$D)\4B)SD&#X?],`U0DX$PAP$PARDC!
M[AM,`T0DZ$@)T$B)RDV-E`*9>8):2(G(2,'@!4@)QDB)R$0!UDF)^DC!YQY)
MP>H"2/?020GZ3"'(2(GW08/B_TC![QM,`TPD\$PATD@)T$B)\DV-A`"9>8):
M2(GP2,'@!4@)QTB)\$0!QTF)R$C!X1Y)P>@"2/?020G(3"'02(GY08/@_TC!
MZ1M,(<)("=!(B?I-C8P!F7F"6DB)^$C!X`5("<%(B?A$`<E)B?%(]]!)P>D"
M2,'F'DP#5"3X20GQ3"'`2(G.08/A_TC![AM,`P0D3"'*2`G02(G*38V4`IEY
M@EI(B<A(P>`%2`G&2(G(1`'628GZ2,'G'DG!Z@)(]]!)B?-)"?I,(<A(B?=!
M@^+_2,'O&TP#3"0(3"'22`G02(GR38V$`)EY@EI(B?!(P>`%2`G'2(GP1`''
M28G(2,'A'DG!Z`)(]]!)"<A,(=!(B?E!@^#_2,'I&TPAPD@)T$B)^DV-C`&9
M>8):2(GX2,'@!4C!YAY)P>L"3`-4)!!("<%)"?-(B?A!@^/_1`')2/?03"':
M2(G.3"'`28GY2,'N&T@)T$C!YQY)P>D"38V4`IEY@EI(B<A,`T0D&$C!X`5)
M"?E(B<I("<9(B<A!@^'_2/?03"'*1`'63"'82(GW28G*2`G02,'A'DC![QM-
MC80`F7F"6DB)\$G!Z@)(P>`%3`-<)"!)"<I("<=(B?!!@^+_2(GR2/?01`''
M3"'(28GP3"'22`G02,'F'DG!Z`)-C9P#F7F"6DD)\$B)^DB)^$&#X/],`TPD
M*$C!X`5(P>H;2`G"3(G`3#'01`':3`-4)#!(,?A(B=%-C8P!H>O9;DB)T$C!
MZ1M(P>`%2`G!1`')28GY2,'G'DG!Z0)(B<Y)"?E(B==(P>X;08/A_TC![P),
MB<A,,<!,`T0D.$@QT$C!XAY-C90"H>O9;D@)UTB)R(/G_TC!X`5("<9(B?A$
M`=9,,<A,`TPD0$@QR$B)\DV-A`"AZ]EN2(GP2,'J&TC!X`5("<)$`<))B<A(
MP>$>2<'H`DD)R$B)T4&#X/](P>D;3(G`2#'X2`-\)$A(,?!-C8P!H>O9;DB)
MT$C!X`5("<%$`<E)B?%(P>8>2<'I`DD)\4B)SD&#X?](P>X;3(G(3#'`3`-$
M)%!(,=!(C;P'H>O9;DB)R$C!X`5("<8!_DB)UTC!XAY(P>\"2`G72(GR@^?_
M2(GX3#'(2,'J&TP#3"182#'(38V$`*'KV6Y(B?!(P>`%2`G"1`'"28G(2,'A
M'DG!Z`))"<A(B=%!@^#_2,'I&TR)P$@Q^$@#?"1@2#'P38V,`:'KV6Y(B=!(
MP>`%2`G!1`')28GQ2,'F'DG!Z0))"?%(B<Y!@^'_2,'N&TR)R$PQP$P#1"1H
M2#'02(V\!Z'KV6Y(B<A(P>`%2`G&`?Y(B==(P>(>2,'O`D@)UTB)\H/G_TB)
M^$PQR$C!ZAM,`TPD<$@QR$V-A`"AZ]EN2(GP2,'@!4@)PD0!PDF)R$C!X1Y)
MP>@"20G(2(G108/@_TC!Z1M,B<!(,?A(`WPD>$@Q\$V-C`&AZ]EN2(G02,'@
M!4@)P40!R4F)\4C!YAY)P>D"20GQ2(G.08/A_TC![AM,B<A,,<!,`X0D@```
M`$@QT$B-O`>AZ]EN2(G(2,'@!4@)Q@'^2(G72,'B'DC![P)("==(B?*#Y_](
MB?A,,<A(P>H;3`.,)(@```!(,<A-C80`H>O9;DB)\$C!X`5("<)$`<))B<A(
MP>$>2<'H`DD)R$B)T4&#X/](P>D;3(G`2#'X2`.\))````!(,?!-C8P!H>O9
M;DB)T$C!X`5("<%$`<E)B?%(P>8>2<'I`DD)\4B)SD&#X?](P>X;3(G(3#'`
M3`.$))@```!(,=!(C;P'H>O9;DB)R$C!X`5("<8!_DB)UTC!XAY(P>\"2`G7
M2(GR@^?_2(GX3#'(2,'J&TP#C"2@````2#'(38V$`*'KV6Y(B?!(P>`%2`G"
M1`'"28G(2,'A'DG!Z`))B=))"<A(B=%)P>H"08/@_TC!Z1M,B<!(,?A(`[PD
MJ````$@Q\$V-C`&AZ]EN2(G02,'@!4@)P40!R4F)\4C!YAY)P>D"28G,20GQ
M2(G.08/A_TC![AM,B<A,,<!,`X0DL````$@QT$C!XAY(C;P'H>O9;DD)TDB)
MR$&#XO](P>`%2`G&3(G0`?Y,,<A)P>P"2#'(2,'A'DB)\DV-A`"AZ]EN20G,
M2(GP08/D_TP#C"2X````2,'@!4C!ZAM(B?-(BXPDR````$@)PDR)X$C!ZP),
M,=!$`<),`Y0DP````$@Q\$C!YAY(B==-C8P!H>O9;D@)\TB)T(/C_TC!X`5(
MP>\;2`G'2(G828G33#'@1`'/2<'K`D@QT$C!XAY)B?A-C90"H>O9;DD)TTB)
M^$&#X_](P>`%2<'H&TD)P$P!Z4R)V$4!T$R)VDP!X4@)V$@AVDR)QD@A^$F)
M^4C![AM("=!(P><>2<'I`D@!P4R)P$D)^4C!X`5!@^'_38G"2`G&3(G(3(G*
M`<Y(BXPDT````$P)V$PAVDPAP$B)]T@)T$C![QM)P>`>3`'I2<'J`D&\UL%B
MRD@!V4T)PD@!P4B)\$&#XO](P>`%3(G22`G'3(G0`<](BXPDV````$P)R$@A
M\$F)^$P!Z4P!V4PARDF)\T@)T$C!YAY)P>@;2`'!2(GX2<'K`DC!X`5)"?-)
M"<!!@^/_00'(2(N,).````!,B=A,"=!,B=I,B<9,(=)((?A(P>X;3`'I2`G0
M3`')28GY2,'G'D@!P4R)P$G!Z0)(P>`%20GY2`G&08/A_P'.2(N,).@```!,
MB<A,"=A,B<I(B?=,(=I,(<!,`>E("=!,`=%-B<)(`<%(B?!(P>\;2,'@!4G!
MX!Y)P>H"2`G'30G"`<]!@^+_2(N,)/````!,B=!,B=))B?A,"<A,(<I)P>@;
M3`'I2"'P2`G03`'928GS2`'!2(GX2,'F'DC!X`5)P>L"20G`20GS00'(08/C
M_TB+C"3X````3(G83(G:3(G&3`G03"'22,'N&TP!Z4@A^$@)T$P!R4F)^4@!
MP4R)P$C!X`5("<8!SDC!YQY)P>D"20GY2(N,)``!``!(B?=!@^'_2,'O&TR)
MR$R)RDP)V$PAVDP!Z4PAP$P!T4V)PD@)T$G!X!Y)P>H"2`'!2(GP30G"2,'@
M!4&#XO]("<=,B=!,B=(!STB+C"0(`0``3`G(3"'*2"'P28GX2`G02<'H&TP!
MZ4P!V4F)\TC!YAY(`<%(B?A)P>L"2,'@!4D)P$$!R$D)\TB+C"00`0``08/C
M_TR)QDR)V$R)VDC![AM,"=!,(=),`>E((?A,`<E)B?E("=!(P><>2<'I`D@!
MP4R)P$D)^4C!X`5!@^'_2`G&3(G(3(G*`<Y(BXPD&`$``$P)V$PAVDPAP$B)
M]T@)T$C![QM,`>E,`=%-B<))P>`>2`'!2(GP2<'J`DC!X`5-"<)("<=!@^+_
M`<](BXPD(`$``$R)T$R)TDF)^$P!Z4P!V4P)R$PARD@A\$F)\TG!Z!M("=!(
MP>8>2<'K`D@!P4B)^$D)\TC!X`5!@^/_20G`3(G83(G:00'(2(N,)"@!``!,
M"=!,(=)((?A,B<9("=!(P>X;3`'I3`')28GY2,'G'D@!P4R)P$G!Z0)(P>`%
M20GY2`G&08/A_P'.2(N,)#`!``!,B<A,"=A,B<I(B?=,(<!,`>E,`=%,(=I-
MB<)("=!)P>`>2,'O&T@!P4B)\$G!Z@)(P>`%30G"2`G'08/B_P'/2(N,)#@!
M``!,B=!,"<A,B=))B?A,(<I((?!)P>@;3`'I2`G03`'928GS2,'F'D@!P4B)
M^$G!ZP)(P>`%20GS20G`08/C_T$!R$B+C"1``0``3(G83`G03(G:3(G&3"'2
M2"'X3`'I2`G03`')28GY2`'!3(G`2,'N&TC!X`5(P><>2<'I`D@)QDD)^0'.
M08/A_TB+C"1(`0``3(G(3(G*2(GW3`G83"':2,'O&TP!Z4PAP$@)T$P!T4V)
MPD@!P4B)\$G!X!Y(P>`%2<'J`D@)QTT)P@'/08/B_TB+C"10`0``3(G03(G2
M28GX3`G(3"'*2<'H&TP!Z4@A\$@)T$P!V4F)\T@!P4B)^$C!X`5)"<!!`<A(
MP>8>2<'K`DD)\TB+C"18`0``3(G&08/C_TC![AM,B=A,B=I,`>E,"=!,(=),
M`<E((?A)B?E("=!(P><>2<'I`D@!P4D)^4R)P$&#X?],`ZPD8`$``$C!X`5(
M"<9,B<A,B<I,"=A,(=H!SDPAP$B)]T@)T$T!U4C![QM)`<5(B?!-B<)(P>`%
M2<'@'DG!Z@)("<=(BY0D:`$``$0![TT)PDF)\$&#XO](B?E)P>@"3(G03`'B
M2,'I&TPQR$P!VD@Q\$C!YAY(`<)(B?A)"?!(P>`%08/@_T@)P4R)P`'12(N4
M)'`!``!,,=!(,?A(B<Y(P>X;3`'B3`'*28GY2,'G'D@!PDB)R$G!Z0)(P>`%
M20GY2`G&08/A_P'62(N4)'@!``!,B<A,,<!(B?=(,<A,`>),`=))B<I(`<)(
MB?!(P>\;2,'@!4C!X1Y)P>H"2`G'20G*`==(BY0D@`$``$&#XO],B=!(B?E,
M,<A(P>D;3`'B2#'P3`'"28GP2,'F'D@!PDB)^$G!Z`)(P>`%20GP2`G!08/@
M_P'12(N4)(@!``!,B<!,,=!(B<Y(,?A(P>X;3`'B3`'*28GY2,'G'D@!PDB)
MR$G!Z0)(P>`%20GY2`G&`=9(BY0DD`$``$&#X?],B<A(B?=,,<!(P>\;3`'B
M2#'(3`'228G*2,'A'D@!PDB)\$G!Z@)(P>`%20G*2`G'08/B_P'72(N4))@!
M``!,B=!,,<A(B?E(,?!(P>D;3`'B3`'"28GP2,'F'D@!PDB)^$G!Z`)(P>`%
M20GP2`G!08/@_P'12(N4)*`!``!,B<!,,=!(B<Y(,?A(P>X;3`'B3`'*28GY
M2`'"2(G(2,'@!4C!YQY)P>D"2`G&20GY`=9(BY0DJ`$``$&#X?],B<A(B?=,
M,<!(P>\;3`'B2#'(3`'228G*2,'A'D@!PDB)\$G!Z@)(P>`%20G*2`G'08/B
M_P'72(N4)+`!``!,B=!,,<A(B?E(,?!(P>D;3`'B3`'"28GP2,'F'D@!PDB)
M^$G!Z`)(P>`%20GP2`G!08/@_P'12(N4)+@!``!,B<!(B<Y,`>),,=!(P>X;
M2#'X3`'*28GY2`'"2(G(2,'G'DC!X`5)P>D"2`G&20GY`=9(BY0DP`$``$&#
MX?],B<A(B?=,,<!(P>\;3`'B2#'(3`'228G*2,'A'D@!PDB)\$G!Z@)(P>`%
M20G*2`G'08/B_P'72(N4),@!``!,B=!,,<A(B?E(,?!(P>D;3`'B3`'"28GP
M2`'"2(GX2,'@!4@)P4C!YAY)P>@"`=%)"?!(BY0DT`$``$&#X/](B<Y,B<!(
MP>X;3`'B3#'02#'X3`'*28GY2`'"2(G(2,'G'DC!X`5)P>D"2`G&20GY`=9(
MBY0DV`$``$&#X?],B<A(B?=)B?-,,<!(P>\;3`'B2#'(3`'228G*2,'A'D@!
MPDB)\$G!Z@)(P>`%20G*2`G'08/B_P'72(N4).`!``!,B=!(B?E(B?M,`>),
M`<),,<A(P>D;2#'P2<'K`DC!YAY(`<)(B?A)"?-(P>`%08/C_TC!ZP)("<%,
MB=@!T4B+E"3H`0``3#'02#'X28G(2,'G'DG!Z!M("?M,`>*#X_],`<I)B<E(
M`<)(B<A(P>`%20G`2(G800'02(N4)/`!``!,,=A(,<A,B<=,B<9(P>\;3`'B
M3`'22`'"3(G`2,'@!4@)QP'72,'A'DG!Z0))"<E(BY0D^`$``$C![@)!@^'_
M2(GY3(G(2,'I&TP!XD@QV$P#I"0``@``3#'`3`':2<'@'D@!PDP)QDB)^$C!
MX`6#YO]("<%(B?!)`=Q,,<@!T4@Q^$B)RDD!Q$B)R$C!X@5(P>@;2`G01`'@
M1`'P2(E%`$B)^$C!YQY(P>@"`TT(2`GX`T40`W481`--($B)30A(B4402(EU
M&$R)32!(@<0(`@``6UU!7$%=05[#3(ED).!,B7PD^$F)_$B)7"302(EL)-A)
MB?=,B6PDZ$R)="3P2(/L.$B%_W4E,<!(BUPD"$B+;"003(MD)!A,BVPD($R+
M="0H3(M\)#!(@\0XPTR+-<>'$`!-A?9TSP^V!X3`=00QP.L7/#U(B?IT]4B#
MP@$/M@*$P'5%B=!$*>!)BRY(A>UTI4QCZ$R)\V:03(GJ3(GF2(GOZ*;D__^%
MP'4*28U$+0"`.#UT&DB+:PA(@\,(2(7M==?I;____V:0/#UUK.NU3"GS2(/`
M`4C!^P-!B1_I5O___V9F9I!F9I!54TB)^TB#[!A(C6PD%&:0,<!(B>Y(B=_H
M`____TB%P'0F2&-$)!1(C13%`````$@#%0J'$`!(@\((2(L"2(7`2(E"^'7P
MZ\A(@\086UW#D$B#[!@QP$B-="04Z,#^__](@\08PV9F9I!F9F:09F:02(/L
M"(,]Y7D0`/]T"XL%W7D0`$B#Q`C#,<"_U5)``.B\____2(7`=`</M@"$P'43
M,<")!;AY$`"+!;)Y$`!(@\0(PSPP#Y7`#[;`Z^5F9I!(@^P(O______H]N/_
M_S'VOX`X0`!(@\0(Z2;F__]FD$B+!;F!$``/MA7*@1``,?93OW140`!(BT`(
MB%`@2(L%G($0`$B+4`A(BP7)@1``#[=`(&8E_P%FB4(B2(L%?H$0`$B+6`CH
MV>/__TB)0RA(BP5J@1``2(M0"$B+!:>!$`!(B4(P2(L%5($0`#'22(M("$B+
M!3>!$`!(A<!T!TB+D*@```!(B5$X2(L%,($0`$B+0`A(QT!``````$B+!1V!
M$`!(BT`(2,=`2`````!(BP4*@1``2(M0"$B+!3^!$`!(B4)06\-F9I!F9I!F
M9I!,B60DZ$B)7"3828G\2(EL).!,B6PD\$R)="3X2('LJ````$B%_W0%@#\`
M=3-(BYPD@````$B+K"2(````3(ND))````!,BZPDF````$R+M"2@````2('$
MJ````,-F9I#H?^/__TB%P$B)Q73`9F:02(GOZ*SD__](A<`/A*$```!(C5@(
MO^!20`"Y`@```/Q(B=[SIG39O]]20`"Y`P```$B)WO.F=,A,B>?H].3__TB)
MWTF)Q>CIY/__08U$!0)(8_CH+.3__TB)V4B)QTF)Q4R)XK[B4D``,<#H].3_
M_TB)YDR)[^CIXO__@\`!=!$/MT0D""4`\```/0!```!T-DR)[^B+XO__3(GO
MZ"/D__](B>_H"^3__TB%P`^%7____TB)[^B*Y/__3(GGZ.+B___I]O[__TR)
M[^C!_O__D.O'9F9FD&9F9I!F9I!F9I!32(G[2(/$@$B)YNA$X?__A<!U&`^W
M1"0()0#P```]`$```'0//0"@``!T"$B#[(`QP%O#2(G?O@(```#H,^+__X7`
M#Y3`2(/L@%L/ML##D$%7,<!!5DF)_D%505152(GU4TB#[!B`/CT/E,!(`<5(
MB>_HW>/__TB-="0408G'3(GW,<#HE_O__TB%P$B)PW0W2(G'Z+OC__]$B?I(
M.=`/@KP````/MD4`2(/%`8@#2(/#`83`=>Y(@\08,<!;74%<05U!7D%?PTB+
M/7&#$`!%,>2X$````$B#/P!T'TB)^DB+0@A!@\0!2(/""$B%P'7O08U$)`)(
MF$C!X`.+%?Y^$`"%T@^%$`$``$B)Q\<%Z7X0``$```#HB.+__TB%P$F)Q0^$
M&0$``$ECQ$B+-0Z#$`!,B>](C1S%`````$B)VN@?XO__3(DM]((0`$B+!>V"
M$`!(QT0#"`````!$B60D%$$/MA9,B?"$T@^%B````(M<)!1%*?=!C7P'`DC!
MXP-(`QVY@A``Z!CB__](A<!(B0,/A*D```"+5"042(L%G8(0`$B+%-!!#[8&
MA,"(`G0E/#UT(4R)]^L.9F:09F:02(/'`3P]=`X/MD<!2(/"`83`B`)UZL8"
M/69F9I!F9I`/MD4`2(/%`8A"`4B#P@&$P'7MZ;_^__^`^CT/A&____](@\`!
M#[8(A,D/A&#___^`^3UU[.E6____2(G&9F:0Z+_?__](A<!(B041@A``=!!)
M8\1(C1S%`````.D+____2(/$&+C_____6UU!7$%=05Y!7\-F9F:09F9FD&9F
MD$%7059)B?Y!54%40;SR4D``55-(@^PX@#W4%0```$C'!"3R4D``2,=$)`CH
M4D``2,=$)!#U4D``2,=$)!CK4D``2,=$)"#P4D``2,=$)"AT5$``#X2E````
M3(L]B!<``$F)Y>L<3(GV3(GG,<#H?OW__TV+90A)@\4(08`\)`!T?3'`3(GG
MZ&7Z__](A<!(B<5TTH`X`'3-3(GV2(G'Z/'?__](A<!URDR)]^A$X?__3(G_
M2(G#Z#GA__](C5P#`4B)[^@LX?__2(T\`^ASX/__28GH2(G#2(G'3(GY3(GR
MOAE40``QP.@XX?__2(G>3(GG,<#H]_S__^ET____2(/$.%M=05Q!74%>05_#
M9F:02(/L.+\"4T``2(L%T'L0`$B)1"0H,<!(BP6*%@``2(D$)$B+!8<6``!(
MB40D"$B+!8,6``!(B40D$$B+!7\6``!(B40D&`^W!7L6``!FB40D(#'`Z#?Y
M__\QP+\+4T``Z"OY__\QP+\34T``Z!_Y__\QP+\<4T``Z!/Y__\QP+\C4T``
MZ`?Y__\QP+\S4T``Z/OX__\QP+\_4T``Z._X__\QP+_54D``Z./X__\QP+](
M4T``Z-?X__\QP+]24T``Z,OX__\QP+]<4T``Z+_X__\QP+]I4T``Z+/X__\Q
MP+]R4T``Z*?X__\QP+]]4T``Z.OX__](A<!T#TB)QK](4T``,<#HU_O__S'`
MOXY30`#HR_C__TB%P'0/2(G&OZ!30``QP.BW^___,<"_JU-``.BK^/__2(7`
M=#9(B<:_/U-``#'`Z)?[__\QP+[74T``OR-30`#HAOO__TB+1"0H2#,%>GH0
M`'512(/$.,-F9I`QP+^[4T``Z&3X__](A<!T$4B)QK_54D``,<#H4/O__^NW
M2(UT)!&_S%-``+D*````_/.F=:-(C70D&[_54D``,<#H*?O__^N0Z.;>__]F
MD$B#[`CHN][__XG'Z`3>__\QTDB%P'0#2(L02(G02(/$",-F9F:09F9FD&9F
MD&9FD%532(G[2(/L"$B%_W0(#[8O0(3M=1!(@\0(O^!20`!;7>GNV___Z,G>
M__](`=A(C5#_2#G3#X.>````2(L]GA0```^V0/\/MC=`./!T">LJ#[8*.,%U
M9DB#Z@%(.=-FD'+N2#G:=2E`.B]TJDB#Q`A;7>F=V___#[8"0#C&=.-(@^H!
M2#G3<N_KV&9FD&9FD$B#Z@%(.=-S"0^V`CH'9I!T[D@IVC')2(U"`D@]``0`
M`'8.2(/$"$B)R%M=PXG(Z[E(@\(!2(G>O\"Z4`#H`MS__[G`NE``Z]I(BST`
M%```ZX!F9F:09F9FD&9FD&9FD$B)7"3P2(EL)/A(@^P82(G[Z/K^__](B<?H
M@M___TB)Q3'`Z/CV__^%P'0*2(7;=`6`.P!U#TB+7"0(2(ML)!!(@\08P[[9
M4T``2(GOZ%+<__](.<5UWTB)WTB+;"002(M<)`A(@\08Z?/W__]F9I!32(/L
M((E\)!Q(B70D$$B-?"0<2(E4)`A(C70D$$B-5"0(Z&W;__^`/:IX$```#X0I
M`0``BT0D'(`-FG@0``.#P`5(8\A(A<D/B$H!``#R2`\JP?(/6`6U$P``9@\N
M!;43```/ATP!``!(C3S-`````.A^W?__2(MT)!!(B<%(B07S?!``3(U)^$B+
M!DC'00C>4T``2,=!$*!50`!(QT$8X5-``$B)`42+1"0<QP6Z?!``!````$&#
M^`%^*4R-2?B_`0```+H(````9F:09F:02(L$%H/'`4B)1`H82(/""$$Y^'_K
M08U`!+X`4D``13'`2)A)QP3!`````(M4)!Q(BSU:?!``@\(#Z";:__^%P(G#
M='%(BSU%?!``Z%3;__\QP+\S4T``Z&3U__](A<!T&4B+/2A\$`#HQ]S__^B2
MW/__B=A(@\0@6\-(BST7?!``2(7_='#H-?[__^O49F:0Z(_;__](A<!(B<=(
MB07N>Q``='3H>]G__\8%`'<0``#IK_[__TB+/=1[$`#H8]K__XG#Z7S___](
MB<A(B<I(T>B#X@%("=#R2`\JP/(/6,#IGO[__[Y@NE``OVM40``QP.B>V/__
MOS]30`#HP/3__TB%P$B)QTB)!8M[$``/A7/____I2?___T"W`>C4VO__05=!
M5D%5051)B?R_/U-``%532(GS2('LJ`0``$B+!7UV$`!(B80DF`0``#'`Z&[T
M__](BRU7$0``3(GG28G%2(GNZ/W9__](A<!T.4R)YK]<4T``,<#H1??__TB+
ME"28!```2#,5-G80`$R)X`^%-`$``$B!Q*@$``!;74%<05U!7D%?PTR)Y^@7
MV___3(L]!!$``$B)WT&)QDR)_N@2V?__2(7`2(G#=*)!@\8!1(ET)`Q,C;0D
MD````&9FD&:0@#L`N.!20`!(#T38387M=`](B=Y,B>_H>-G__X7`='Y(B=_H
MO-K__XG!2)@/MD0#_SI%`'4=C4'_2)A(C108D`^V0O_&`@"#Z0%(@^H!.D4`
M=.V+1"0,`<@]_P,```^/*/___TV)X$B)Z4B)VKX95$``3(GW,<#HF-K__TB-
M="003(GWZ(O8__^%P'41#[=$)!@E`/```#T`@```=!LQ_TR)_NA,V/__2(7`
M2(G##X5,____Z=/^__^^`0```$R)]^@^V/__A<!UU$R)]K]<4T``Z`GV__],
MB??H)=?__TF)Q.FT_O__Z+C9__]F9F:005=!5D%505154TB!['B!``!(BP78
M=!``2(F$)&B!```QP$B)?"00OS]30`!(QT0D8.130`!(QT0D:.Q30`!(QT0D
M<.!20`!(QT0D>'140`!(QT0D,*!30`!(QT0D.)E30`!(QT0D0/930`!(QT0D
M2.=30`!(QT0D4/Y30`!(QT0D6'140`!(QX0D@`````)40`!(QX0DB`````=4
M0`!(QX0DD````'140`#H0?+__TB%P$B)PW0)@#@`#X6D`@``,<!(C9PD@```
M`.@!^O__2(7`28G$#X1I`@``00^V!"2$P'0[3(GA#[[`A<!X(CL%5'00`'T:
M2&/02(L%4'00`/=$T$``!0``=0EF9I!F9I#&`5\/MD$!2(/!`83`=<A(C6PD
M,$4Q[>L09F9FD&9FD$B#Q0A-A>UU/$B+?0"`/P`/A#8"```QP.BC\?__2(7`
M2(G#=-M(B<?H0_3__X7`=,](B=](@\4(Z*?5__])B<5-A>UTQ$R)[^AWV/__
M3(GG2(G#Z&S8__^-A`,$!```2&/82(G?Z*K7__](B=])B<;HG]?__TB+%30.
M``!-B>%!N-E30`!(B<=)B<>^%U1``#'`2(G12(E4)!A,B>KH4MC__[[M`0``
M3(G_Z%77__\QP+_K4D``Z`7Q__](A<`/A&,!``!(B<?H&-7__TB+3"002(G&
M2(LYZ$3\__](A<!(B<,/A#\!``!(B=_HU-?__X/X`T&)P`^/B@$``#'`Z-WP
M__^%P'46,?9(B=_HL];__X7`B40D)`^%XP$``+[74T``O]520``QP.B2\___
MZ''7__](BTPD&$&)P$&Y=%1``$R)^KX^5$``3(GW,<`QV^B?U___ZSCHZ-7_
M_X,X$9!U/^@]U___2(M,)!B#PP%!B<!!B=E,B?J^3%1``$R)]S'`2,<$)'14
M0`#H9=?__[[M`0``3(GWZ&C6__^#P`%TMDR)_^BKUO__OS]30`!,B?8QP.@(
M\___3(GWZ!#U__](BY0D:($``$@S%?%Q$`!,B?`/A1L&``!(@<1X@0``6UU!
M7$%=05Y!7\-F9I!F9I`QP.C)[___2(7`=`M(B<?HX-/__TF)Q$B#PPA-A>0/
MA9?]__](BSN`/P!UU$&\$%1``.G(_?__2(M$)!!(BQCIM/[__TB)Q^B4]/__
M2(G?Z*#3__])B<;I=/___TB-;"1@ZPU(@\4(387M#X7E_?__2(M=`(`[``^$
MV/W__TB)W^C[\?__A<!TVDB)W^ACT___28G%Z\U(F+\@5$``2(UT`_RX!0``
M`/Q(B<'SI@^%6?[__T&#^`1T&$&-0/Q(BU0D&$B8#[9$`_\Z`@^%._[__TB+
M3"002(MI"$B%[0^$*?[__TB)[^CIU?__2(/X`P^&%_[__TB-=`7\OR540`"Y
M!0```/SSID@/1-WI_/W__[H"````2,?&[O___XG'Z$'4__^+?"0D2(VT)*``
M``"Z!@```.B[U?__@+PDH`````!U#H"\)*$```!##X0\!```BWPD)$R-K"2@
M@```,?8QTDF-;3CH^M/__[^)J\WOOO[<NIBY\.'2PTC'A"2@@````2-%9TB)
MO"2H@```2(FT)+"```!(QX0DN(```'94,A!(B8PDP(```$C'A"3(@```````
M`$C'A"30@````````,>$)!B!````````9F9FD(M\)"1(C;0DH````+H`@```
MZ`[5__^%P$&)Q`^.)0$``$B+C"3(@```26/42(N$)-"```!(C9PDH````(TT
MT4@YSDB)M"3(@```2(/0`$C!ZAU(B80DT(```$@!E"30@```BY0D&($``(72
M=%+K<9!(BP-,B>]!@^Q`28E%.$B+0PA(B44(2(M#$$B)11!(BT,82(E%&$B+
M0R!(B44@2(M#*$B)12A(BT,P2(E%,$B+0SA(@\-`2(E%..@AUO__08/\/W^K
M26/42(G>2(GOZ*'3__]$B:0D&($``.D@____N$````!(8_I(C;0DH````"G0
M2(U\/0!!.<2)PT$/3MQ(8\-(B<)(B40D*.ADT___B=@#A"08@0``@_A`B80D
M&($```^%U_[__T$IW$B-G"2@````2`-<)"A,B>_HG]7__^EY____BWPD).B%
MTO__2(N<),B```!(BZPDT(```$B)V$C!Z`.#X#](8]"#P`&#^#A!QD05.(`/
MCB$"``!(8_BZ0````#'V*<)*C7PO.$ACTNB]T?__3(GOZ$'5__])C7TXN0<`
M```QP/SS2*M(B>A,B>]`B*PD$X$``$C!Z!B(G"07@0``3(VL)""!``"(A"00
M@0``2(GH3(VD)%"!``!(P>@0B(0D$8$``$B)Z$R)[4C!Z`B(A"02@0``2(G8
M2,'H&(B$)!2!``!(B=A(P>@0B(0D%8$``$B)V#';2,'H"(B$)!:!``#HLM3_
M_TB+E"2@@```2(G0B)0D4X$``$C!Z!B(A"10@0``2(G02,'H$(B$)%&!``!(
MB=!(BY0DJ(```$C!Z`B(A"12@0``2(G0B)0D5X$``$C!Z!B(A"14@0``2(G0
M2,'H$(B$)%6!``!(B=!(BY0DL(```$C!Z`B(A"16@0``2(G0B)0D6X$``$C!
MZ!B(A"18@0``2(G02,'H$(B$)%F!``!(B=!(BY0DN(```$C!Z`B(A"1:@0``
M2(G0B)0D7X$``$C!Z!B(A"1<@0``2(G02,'H$(B$)%V!``!(B=!(BY0DP(``
M`$C!Z`B(A"1>@0``2(G0B)0D8X$``$C!Z!B(A"1@@0``2(G02,'H$(B$)&&!
M``!(B=!(P>@(B(0D8H$``&9FD&:00@^V%"-(B>\QP+XY5$``2(/#`4B#Q0+H
MR-'__TB#^Q1UWL:$)$B!````0;ET5$``38GH2(M,)!A,B?J^*E1``$R)]S'`
MZ)K1___I0OK__[HX````2&/X,?8IPDJ-?"\X2&/2Z)S/___I\?W__X"\)*(`
M``!!#X6V^___@+PDHP```$,/A:C[__^`O"2D````2`^%FOO__X"\)*4```!%
M#X6,^___BWPD)+H"````2,?&QO___^B*S___BWPD)$B-M"2@````NBD```#H
M!-'__TR-A"2@````0;ET5$``Z5#____HC-#__V9F9I!F9F:02(E<).A(B6PD
M\$R)9"3X2('L.`@``$B-G"00!```2(L%FVL0`$B)A"08"```,<#H<-#__[E=
M5$``B<*^8E1``#'`2(G?Z*K0__^%P'DV,>U(BY0D&`@``$@S%6%K$`!(B>AU
M8$B+G"0@"```2(NL)"@(``!,BZ0D,`@``$B!Q#@(``##2(G?N@`$``!(B>;H
M@-#__X7`B<-XM(UX`4AC_^AOS___2(7`=*1(8]M(B<5(B>9(B=I(B<?H=L__
M_\8$*P#KC.B[S___9F9FD&9FD.DK____9F9FD&9F9I!F9I!!5#'`OR-30`#&
M!2QK$``!55/HR>C__TB%P'0)@#@Q#X29`0``,<#HU.[__[H+````O@$```"_
M;E1``.C$SO__2(7`#X2`````,>V#/6YO$``!2(M`$$R+8"A^7+L(````ZRI(
MBW<02(L%6F\0`$B+/!CH'<[__X7`=3V#Q0%(@\,(C44!.04U;Q``?BLQTHGN
M3(GGZ#O/__](A<!T&DB+./9'#01UO#'VN@(```#H$<S__TB)QNNOBQ4";Q``
MC4+_.>@/A,\```"Z!0```+X!````OW-40`#H)\[__TB%P$B)PW0B2(M`$+YU
M5$``2(LXZ*[,__](BT,02(LX]D<.0`^%S@```+H%````O@$```"_>U-``.CI
MS?__2(7`2(G%="<QP+]<4T``Z+'G__](A<!(B<(/A*H```!(BT402(G62(LX
MZ%K,__\QP+\_4T``Q@7D:1```$C'!75I$```````Z'CG__](A<!(B05&;A``
M#X30````ONT!``!(B<?HG\W__X7`=`J#^!%T!8/X_W5[6UU!7,.#Z@$/CBC_
M__^[`0```$R)YX/#`>ACR___.1T);A``?^WI"____X!X`0`/A&3^__]F9F:0
M9F9FD.E0_O__Z$K+__]F9I!F9I#I(O___^@&_O__2(7`2(G#=#M(BT402(G>
M2(LXZ*/+__](B=_H:\W__^D\____B<%(BP6Q;1``2(L5FFT0`+\@54``2(LP
M,<#HA\K__TB+51!(BP60;1``2(LZ2(LPZ&'+___I`O___TB+/7EM$`#HG//_
M_TB)!5UM$`!(BT402(L=8FT0`$B+./9'#01T.DB+?Q!(B=[H6<K__XG#2(M%
M$$B+./9'#01T,$B+1Q!(B<)(BP4P;1``B=F_\%1``$B+,#'`Z`O*__^Z`@``
M`#'VZ`_*__](B<?KN;H"````,?;H_LG__^O&9F9FD&9F9I"Z>E1``+ZT'4``
MOX140`#IT,K__V9F9I!F9F:09F9FD$B#[`CHU____[ET5$``13'`OA!/0`!(
MB<J_H%1``$B#Q`CI'<K__Y"0D)"0D)"0D$B+!8EE$`!32(/X_W05,=O_T$B+
M@[BW4`!(@^L(2(/X_W7M6\.0D)!(@^P(Z+_-__](@\0(PP``````````````
M````````````````````)$9R965"4T0Z('-R8R]L:6(O8W-U+V%M9#8T+V-R
M=&DN4RQV(#$N-RXS,"XQ+C(N,2`R,#`Y+S$P+S(U(#`Q.C$P.C(Y(&ME;G-M
M:71H($5X<"`D`%!!4E]#3$5!3@`N+@`E<R\E<P!,24)0051(`$193$1?3$E"
M4D%265]0051(`%!%4DPU3$E"`%!%4DQ,24(`4$523#5/4%0`4$523$E/`%!!
M4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?5$5-4`!005)?1$5"54<`
M4$%27T-!0TA%`%!!4E]04D]'3D%-10!005)?05)'0P!005)?05)'5E\P`%!!
M4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!0
M05)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`
M<&%R+0`M90`M+0!#.EQ414U0`"]V87(O=&UP+P!414U01$E2`%1-4`!54T52
M`%5315).04U%`%-94U1%30`E<R5S)7,E<P!P87)L`"YP87(`)7,E<V-A8VAE
M+25S)7,`)3`R>``E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`9FEL
M90`O<')O8R\E:2\E<P!!4D=6`!@`<&5R;`!P97)L>'-I+F,`1'EN84QO861E
M<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`#H``%]?
M14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@``````````#T4T``````
M`+540```````)7,Z(&5X96-U=&EO;B!O9B`E<R!F86EL960@+2!A8F]R=&EN
M9R!W:71H("5I+@H`)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@=&5M<&]R87)Y
M('-U8F1I<F5C=&]R>2`E<R!F86EL960@+2!A8F]R=&EN9R!W:71H("5I+@H`
M`````````````````````,!#<&%R+G!L````````````````````````````
M```````C(2]U<W(O8FEN+W!E<FP*979A;"`G97AE8R`O=7-R+V)I;B]P97)L
M("`M4R`D,"`D>S$K(B1`(GTG"B`@("!I9B`P.R`C(&YO="!R=6YN:6YG('5N
M9&5R('-O;64@<VAE;&P*"G!A8VMA9V4@7U]P87)?<&P["@HC("TM+2!4:&ES
M('-C<FEP="!M=7-T(&YO="!U<V4@86YY(&UO9'5L97,@870@8V]M<&EL92!T
M:6UE("TM+0HC('5S92!S=')I8W0["@HC;&EN92`Q-3@*"FUY("@D<&%R7W1E
M;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?
M0TQ%04Y]*2!["B`@("!R97%U:7)E($9I;&4Z.E1E;7`["B`@("!R97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PH@("`@<F5Q=6ER92!&:6QE.CI3<&5C.PH@("`@
M;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M
M<"D["B`@("!O=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B
M?2D["B`@("!&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@
M<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*("`@(')M9&ER("1P87)?
M=&5M<#L*("`@(",@1&]N)W0@<F5M;W9E('1O<&1I<B!B96-A=7-E('1H:7,@
M8V%U<V5S(&$@<F%C92!W:71H(&]T:&5R(&%P<',*("`@(",@=&AA="!A<F4@
M=')Y:6YG('1O('-T87)T+@H*("`@(&EF("@M9"`D<&%R7W1E;7`@)B8@)%Y/
M(&YE("=-4U=I;C,R)RD@>PH@("`@("`@(",@4V]M971H:6YG('=E;G0@=W)O
M;F<@=6YL:6YK:6YG('1H92!T96UP;W)A<GD@9&ER96-T;W)Y+B`@5&AI<PH@
M("`@("`@(",@='EP:6-A;&QY(&AA<'!E;G,@;VX@<&QA=&9O<FUS('1H870@
M9&ES86QL;W<@=6YL:6YK:6YG('-H87)E9`H@("`@("`@(",@;&EB<F%R:65S
M(&%N9"!E>&5C=71A8FQE<R!T:&%T(&%R92!I;B!U<V4N(%5N;&EN:R!W:71H
M(&$@8F%C:V=R;W5N9`H@("`@("`@(",@<VAE;&P@8V]M;6%N9"!S;R!T:&4@
M9FEL97,@87)E(&YO(&QO;F=E<B!I;B!U<V4@8GD@=&AI<R!P<F]C97-S+@H@
M("`@("`@(",@1&]N)W0@9&\@86YY=&AI;F<@;VX@5VEN9&]W<R!B96-A=7-E
M(&]U<B!P87)E;G0@<')O8V5S<R!W:6QL"B`@("`@("`@(R!T86ME(&-A<F4@
M;V8@8VQE86YI;F<@=&AI;F=S('5P+@H*("`@("`@("!M>2`D=&UP(#T@;F5W
M($9I;&4Z.E1E;7`H"B`@("`@("`@("`@(%1%35!,051%(#T^("=T;7!86%A8
M6"<L"B`@("`@("`@("`@($1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M
M92@D=&]P9&ER*2P*("`@("`@("`@("`@4U5&1DE8(#T^("<N8VUD)RP*("`@
M("`@("`@("`@54Y,24Y+(#T^(#`L"B`@("`@("`@*3L*"B`@("`@("`@<')I
M;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[
M(&1O"B`@(')M("UR9B`G)'!A<E]T96UP)PH@("!I9B!;(%PA("UD("<D<&%R
M7W1E;7`G(%T[('1H96X*("`@("`@(&)R96%K"B`@(&9I"B`@('-L965P(#$*
M("`@>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA
M;64@+B`B)PHB.PH@("`@("`@("`@("!C:&UO9"`P-S`P+"1T;7`M/F9I;&5N
M86UE.PH@("`@("`@(&UY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D
M978O;G5L;"`R/B8Q("8G.PH@("`@("`@(&-L;W-E("1T;7`["B`@("`@("`@
M<WES=&5M*"1C;60I.PH@("`@("`@(&]U=',H<7$H4W!A=VYE9"!B86-K9W)O
M=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"B`@("`@("`@("`@
M("`N("1T;7`M/F9I;&5N86UE*3L*("`@('T*?2!]"@I"14=)3B!["B`@("!)
M;G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ
M4$%2.CI"3T]4.PH*("`@(&5V86P@>PH*7W!A<E]I;FET7V5N=B@I.PH*:68@
M*&5X:7-T<R`D14Y6>U!!4E]!4D=67S!](&%N9"`D14Y6>U!!4E]!4D=67S!]
M("D@>PH@("`@0$%21U8@/2!M87`@)$5.5GLB4$%27T%21U9?)%\B?2P@*#$@
M+BX@)$5.5GM005)?05)'0WT@+2`Q*3L*("`@("0P(#T@)$5.5GM005)?05)'
M5E\P?3L*?0IE;'-E('L*("`@(&9O<B`H:V5Y<R`E14Y6*2!["B`@("`@("`@
M9&5L971E("1%3E9[)%]](&EF("]>4$%27T%21U9?+SL*("`@('T*?0H*;7D@
M)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*"B,@9FEX("1P<F]G;F%M92!I
M9B!I;G9O:V5D(&9R;VT@4$%42`IM>2`E0V]N9FEG(#T@*`H@("`@<&%T:%]S
M97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"B`@("!?
M97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO
M(#\@)RYE>&4G(#H@)R<I+`H@("`@7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O
M7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*"E]S971?<')O9VYA;64H
M*3L*7W-E=%]P87)?=&5M<"@I.PH*(R!-86=I8R!S=')I;F<@8VAE8VMI;F<@
M86YD(&5X=')A8W1I;F<@8G5N9&QE9"!M;V1U;&5S('M[>PIM>2`H)'-T87)T
M7W!O<RP@)&1A=&%?<&]S*3L*>PH@("`@;&]C86P@)%-)1WM?7U=!4DY?7WT@
M/2!S=6(@>WT["@H@("`@(R!#:&5C:R!F:6QE('1Y<&4L(&=E="!S=&%R="!O
M9B!D871A('-E8W1I;VX@>WM["B`@("!O<&5N(%]&2"P@)SPG+"`D<')O9VYA
M;64@;W(@;&%S=#L*("`@(&)I;FUO9&4H7T9(*3L*"B`@("!M>2`D8G5F.PH@
M("`@<V5E:R!?1D@L("TX+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#@["B`@
M("!L87-T('5N;&5S<R`D8G5F(&5Q(")<;E!!4BYP;5QN(CL*"B`@("!S965K
M(%]&2"P@+3$R+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("!S965K
M(%]&2"P@+3$R("T@=6YP86-K*").(BP@)&)U9BDL(#(["B`@("!R96%D(%]&
M2"P@)&)U9BP@-#L*"B`@("`D9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*
M("`@(",@?7U]"@H@("`@(R!%>'1R86-T:6YG(&5A8V@@9FEL92!I;G1O(&UE
M;6]R>2![>WL*("`@(&UY("5R97%U:7)E7VQI<W0["B`@("!W:&EL92`H)&)U
M9B!E<2`B1DE,12(I('L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@
M("`@("!R96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["@H@("`@
M("`@(&UY("1F=6QL;F%M92`]("1B=68["B`@("`@("`@;W5T<RAQ<2A5;G!A
M8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PH@("`@("`@(&UY("1C<F,@
M/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@
M=6YD968["B`@("`@("`@;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]
M?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PH*("`@("`@("!R96%D(%]&2"P@
M)&)U9BP@-#L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@
M)&)U9BD["@H@("`@("`@(&EF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^
M("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PH@("`@("`@("`@("!M>2`H)&]U
M="P@)&9I;&5N86UE*2`](%]T96UP9FEL92@D97AT+"`D8W)C*3L*("`@("`@
M("`@("`@:68@*"1O=70I('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&]U
M="D["B`@("`@("`@("`@("`@("!P<FEN="`D;W5T("1B=68["B`@("`@("`@
M("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@("`@("`@("`@8VAM;V0@,#<U
M-2P@)&9I;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*("`@
M("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@
M)&9U;&QN86UE.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H("1F=6QL;F%M
M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@
M*2!["B`@("`@("`@("`@(",@<VAO=6QD(&)E(&UO=F5D('1O(%]T96UP9FEL
M92@I"B`@("`@("`@("`@(&UY("1F:6QE;F%M92`]("(D14Y6>U!!4E]414U0
M?2\D8F%S96YA;64D97AT(CL*("`@("`@("`@("`@;W5T<R@B4TA,24(Z("1F
M:6QE;F%M95QN(BD["B`@("`@("`@("`@(&]P96X@;7D@)&]U="P@)SXG+"`D
M9FEL96YA;64@;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1O=70I
M.PH@("`@("`@("`@("!P<FEN="`D;W5T("1B=68["B`@("`@("`@("`@(&-L
M;W-E("1O=70["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@
M("`D<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0H@("`@("`@("`@("`D4$%2
M.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*("`@("`@("`@
M("`@("`@(&)U9B`]/B`D8G5F+`H@("`@("`@("`@("`@("`@8W)C(#T^("1C
M<F,L"B`@("`@("`@("`@("`@("!N86UE(#T^("1F=6QL;F%M92P*("`@("`@
M("`@("`@?3L*("`@("`@("!]"B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0[
M"B`@("!]"B`@("`C('U]?0H*("`@(&QO8V%L($!)3D,@/2`H<W5B('L*("`@
M("`@("!M>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["@H@("`@("`@(')E='5R
M;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*"B`@("`@("`@;7D@)&9I
M;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@
M>PH@("`@("`@("`@("!M>2`D:V5Y.PH@("`@("`@("`@("!F;W)E86-H("AK
M97ES("5R97%U:7)E7VQI<W0I('L*("`@("`@("`@("`@("`@(&YE>'0@=6YL
M97-S("]<421M;V1U;&5<120O.PH@("`@("`@("`@("`@("`@)&ME>2`]("1?
M.R!L87-T.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D["B`@("`@("`@?2!O
M<B!R971U<FX["@H@("`@("`@("1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D
M9FEL96YA;64O)&UO9'5L92(["@H@("`@("`@(&EF("@D14Y6>U!!4E]#3$5!
M3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["B`@("`@("`@("`@
M(&UY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["B`@
M("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@<')I;G0@)&9H
M("1F:6QE;F%M92T^>V)U9GT["B`@("`@("`@("`@('-E96LH)&9H+"`P+"`P
M*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@("`@("!]"B`@("`@("`@
M96QS92!["B`@("`@("`@("`@(&UY("@D;W5T+"`D;F%M92D@/2!?=&5M<&9I
M;&4H)RYP;2<L("1F:6QE;F%M92T^>V-R8WTI.PH@("`@("`@("`@("!I9B`H
M)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@
M("`@("`@("`@('!R:6YT("1O=70@)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@
M("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@;W!E;B!M>2`D9F@L("<\)RP@)&YA;64@;W(@9&EE("0A.PH@("`@("`@
M("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@(')E='5R;B`D9F@["B`@
M("`@("`@?0H*("`@("`@("!D:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C
M86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*("`@('TL($!)3D,I.PH*("`@(",@
M3F]W(&QO860@86QL(&)U;F1L960@9FEL97,@>WM["@H@("`@(R!I;FET:6%L
M:7IE('-H87)E9"!O8FIE8W0@<')O8V5S<VEN9PH@("`@<F5Q=6ER92!84TQO
M861E<CL*("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I<F4@0V%R
M<#HZ2&5A=GD["B`@("!R97%U:7)E($5X<&]R=&5R.CI(96%V>3L*("`@(%!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*"B`@("`C(&YO=R!L970G
M<R!T<GD@9V5T=&EN9R!H96QP97(@;6]D=6QE<R!F<F]M('=I=&AI;@H@("`@
M<F5Q=6ER92!)3SHZ1FEL93L*"B`@("`C(&QO860@<F5S="!O9B!T:&4@9W)O
M=7`@:6X*("`@('=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R
M97%U:7)E7VQI<W0I6S!=*2!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP
M;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!U
M;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!
M3B\I('L*("`@("`@("`@("`@(R!R97%U:7)E(&UO9'5L97,L(&1O(&]T:&5R
M(&5X96-U=&%B;&4@9FEL97,*("`@("`@("`@("`@:68@*"1F:6QE;F%M92`]
M?B`O7"YP;6,_)"]I*2!["B`@("`@("`@("`@("`@("!R97%U:7)E("1F:6QE
M;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@
M("`@("`@("`@(",@4VMI<"!!8W1I=F53=&%T92=S('-I=&5C=7-T;VUI>F4N
M<&P@9FEL93H*("`@("`@("`@("`@("`@(&1O("1F:6QE;F%M92!U;FQE<W,@
M)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@("`@(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1F
M:6QE;F%M97T["B`@("!]"@H@("`@(R!]?7T*"B`@("!L87-T('5N;&5S<R`D
M8G5F(&5Q(")02UPP,#-<,#`T(CL*("`@("1S=&%R=%]P;W,@/2`H=&5L;"!?
M1D@I("T@-#L*?0HC('U]?0H*(R!!<F=U;65N="!P<F]C97-S:6YG('M[>PIM
M>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H
M95]N86UE*3L*"F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET
M:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0H*)'%U:65T
M(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PHC($1O;B=T('-W86QL;W<@
M87)G=6UE;G1S(&9O<B!C;VUP:6QE9"!E>&5C=71A8FQE<R!W:71H;W5T("TM
M<&%R+6]P=&EO;G,*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G
M+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["B`@("!M>2`E9&ES=%]C;60@
M/2!Q=R@*("`@("`@("!P("`@8FQI8E]T;U]P87(*("`@("`@("!I("`@:6YS
M=&%L;%]P87(*("`@("`@("!U("`@=6YI;G-T86QL7W!A<@H@("`@("`@(',@
M("!S:6=N7W!A<@H@("`@("`@('8@("!V97)I9GE?<&%R"B`@("`I.PH*("`@
M(",@:68@=&AE(&%P<"!I<R!I;G9O:V5D(&%S(")A<'!N86UE("TM<&%R+6]P
M=&EO;G,@+2UR975S92!04D]'4D%-($!04D]'7T%21U8B+`H@("`@(R!U<V4@
M=&AE(&%P<"!T;R!R=6X@=&AE(&=I=F5N('!E<FP@8V]D92!I;G-T96%D(&]F
M(&%N>71H:6YG(&9R;VT@=&AE"B`@("`C(&%P<"!I='-E;&8@*&)U="!S=&EL
M;"!S970@=7`@=&AE(&YO<FUA;"!A<'`@96YV:7)O;FUE;G0@86YD($!)3D,I
M"B`@("!I9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PH@
M("`@("`@('-H:69T($!!4D=6.PH@("`@("`@("1%3E9[4$%27T%04%]21553
M17T@/2!S:&EF="!`05)'5CL*("`@('T*("`@(&5L<V4@>R`C(&YO<FUA;"!P
M87)L(&)E:&%V:6]U<@H*("`@("`@("!M>2!`861D7W1O7VEN8SL*("`@("`@
M("!W:&EL92`H0$%21U8I('L*("`@("`@("`@("`@)$%21U9;,%T@/7X@+UXM
M*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*"B`@("`@("`@("`@
M(&EF("@D,2!E<2`G22<I('L*("`@("`@("`@("`@("`@('!U<V@@0&%D9%]T
M;U]I;F,L("0R.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D
M,2!E<2`G32<I('L*("`@("`@("`@("`@("`@(&5V86P@(G5S92`D,B(["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=!)RD@>PH@
M("`@("`@("`@("`@("`@=6YS:&EF="!`<&%R7V%R9W,L("0R.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G3R<I('L*("`@("`@
M("`@("`@("`@("1O=70@/2`D,CL*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!E;'-I9B`H)#$@97$@)V(G*2!["B`@("`@("`@("`@("`@("`D8G5N9&QE
M(#T@)W-I=&4G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D
M,2!E<2`G0B<I('L*("`@("`@("`@("`@("`@("1B=6YD;&4@/2`G86QL)SL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)W$G*2![
M"B`@("`@("`@("`@("`@("`D<75I970@/2`Q.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&5L<VEF("@D,2!E<2`G3"<I('L*("`@("`@("`@("`@("`@
M(&]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P
M96X@;&]G.B`D(2(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@
M*"0Q(&5Q("=4)RD@>PH@("`@("`@("`@("`@("`@)&-A8VAE7VYA;64@/2`D
M,CL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@<VAI9G0H0$%21U8I.PH*
M("`@("`@("`@("`@:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["B`@
M("`@("`@("`@("`@("!D96QE=&4@)$5.5GLG4$%27U1%35`G?3L*("`@("`@
M("`@("`@("`@(&EN:71?:6YC*"D["B`@("`@("`@("`@("`@("!R97%U:7)E
M(%!!4CHZ1&ES=#L*("`@("`@("`@("`@("`@("9[(E!!4CHZ1&ES=#HZ)&-M
M9")]*"D@=6YL97-S($!!4D=6.PH@("`@("`@("`@("`@("`@)GLB4$%2.CI$
M:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*("`@("`@("`@("`@("`@(&5X
M:70["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@('5N<VAI9G0@
M0$E.0RP@0&%D9%]T;U]I;F,["B`@("!]"GT*"B,@6%A8("TM(&%D9"`M+7!A
M<BUD96)U9R!S=7!P;W)T(0H*(R!]?7T*"B,@3W5T<'5T(&UO9&4@*"U/*2!H
M86YD;&EN9R![>WL*:68@*"1O=70I('L*("`@('L*("`@("`@("`C;&]C86P@
M)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G
M.PH@("`@("`@(')E<75I<F4@24\Z.D9I;&4["B`@("`@("`@<F5Q=6ER92!!
M<F-H:79E.CI::7`["B`@("!]"@H@("`@;7D@)'!A<B`]('-H:69T*$!!4D=6
M*3L*("`@(&UY("1Z:7`["@H*("`@(&EF("AD969I;F5D("1P87(I('L*("`@
M("`@("!O<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I
M;F0@)R1P87(G.B`D(2(["B`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@
M(&)L97-S*"1F:"P@)TE/.CI&:6QE)RD["@H@("`@("`@("1Z:7`@/2!!<F-H
M:79E.CI::7`M/FYE=SL*("`@("`@("`H("1Z:7`M/G)E861&<F]M1FEL94AA
M;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"B`@
M("`@("`@("`@(&]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*("`@
M('T*"@H@("`@;7D@)65N=B`](&1O('L*("`@("`@("!I9B`H)'II<"!A;F0@
M;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PH@("`@
M("`@("`@("`D;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*("`@("`@("`@("`@
M)&UE=&$@/7X@<R]>7%,N*B\O;7,["B`@("`@("`@("`@("1M971A(#U^("]>
M("`H6UXZ72LI.B`H+BLI)"]M9SL*("`@("`@("!]"B`@("!].PH*("`@(",@
M3W!E;B!I;G!U="!A;F0@;W5T<'5T(&9I;&5S('M[>PH@("`@;&]C86P@)"\@
M/2!<-#L*"B`@("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@("`@;W!E;B!0
M05(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*("`@("`@("!B:6YM
M;V1E*%!!4BD["B`@("`@("`@9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE
M(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PH@("`@?0H*("`@($-R
M96%T95!A=&@H)&]U="D@.PH@("`@"B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W*`H@("`@("`@("1O=70L"B`@("`@("`@24\Z.D9I;&4Z.D]?0U)%050H
M*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H
M*2P*("`@("`@("`P-S<W+`H@("`@*2!O<B!D:64@)"$["B`@("!B:6YM;V1E
M*"1F:"D["@H@("`@)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A
M7W!O<R`Z('5N9&5F.PH@("`@<V5E:R!?1D@L(#`L(#`["B`@("!M>2`D;&]A
M9&5R(#T@<V-A;&%R(#Q?1D@^.PH@("`@:68@*"$D14Y6>U!!4E]615)"051)
M37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["B`@("`@("`@
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@("`@("`@4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*("`@
M('T*("`@(&9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*("`@
M("`@("!M>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PH@("`@("`@("1V
M86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PH@("`@("`@(&UY
M("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*("`@
M("`@("!M>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PH@
M("`@("`@("1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*("`@("`@("`@("`@
M)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D
M<V5T*2DI"B`@("`@("`@?65G.PH@("`@?0H@("`@)&9H+3YP<FEN="@D;&]A
M9&5R*3L*("`@("0O(#T@=6YD968["B`@("`C('U]?0H*("`@(",@5W)I=&4@
M8G5N9&QE9"!M;V1U;&5S('M[>PH@("`@:68@*"1B=6YD;&4I('L*("`@("`@
M("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("`@("`@4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PH@("`@("`@(&EN:71?:6YC*"D["@H@("`@("`@
M(')E<75I<F5?;6]D=6QE<R@I.PH*("`@("`@("!M>2!`:6YC(#T@<V]R="![
M"B`@("`@("`@("`@(&QE;F=T:"@D8BD@/#T^(&QE;F=T:"@D82D*("`@("`@
M("!](&=R97`@>PH@("`@("`@("`@("`A+T)31%!!3B\*("`@("`@("!](&=R
M97`@>PH@("`@("`@("`@("`H)&)U;F1L92!N92`G<VET92<I(&]R"B`@("`@
M("`@("`@("@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD
M"B`@("`@("`@("`@("`D7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X
M<'TI.PH@("`@("`@('T@0$E.0SL*"B`@("`@("`@(R!&:6QE(&5X:7-T<R!T
M97-T(&%D9&5D('1O(&9I>"!25"`C-#$W.3`Z"B`@("`@("`@(R!&=6YN>2P@
M;F]N+65X:7-T:6YG(&5N=')Y(&EN(%\\+BXN+F%U=&\O0V]M<')E<W,O4F%W
M+UIL:6(O875T;W-P;&ET+FEX+@H@("`@("`@(",@5&AI<R!I<R!A(&)A;F0M
M86ED(&9I>"!W:71H(&YO(&1E97!E<B!G<F%S<"!O9B!T:&4@:7-S=64N"B`@
M("`@("`@(R!3;VUE8F]D>2!P;&5A<V4@9V\@=&AR;W5G:"!T:&4@<&%I;B!O
M9B!U;F1E<G-T86YD:6YG('=H870G<R!H87!P96YI;F<L"B`@("`@("`@(R!)
M(&9A:6QE9"X@+2T@4W1E9F9E;@H@("`@("`@(&UY("5F:6QE<SL*("`@("`@
M("`O7E\\*"XK*20O(&%N9"`M92`D,2!A;F0@)&9I;&5S>R0Q?2LK(&9O<B!K
M97ES("4Z.CL*("`@("`@("`D9FEL97-[)%]]*RL@9F]R('9A;'5E<R`E24Y#
M.PH*("`@("`@("!M>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?
M97AT?3L*("`@("`@("!M>2`E=W)I='1E;CL*"B`@("`@("`@9F]R96%C:"`H
M<V]R="!K97ES("5F:6QE<RD@>PH@("`@("`@("`@("!M>2`H)&YA;64L("1F
M:6QE*3L*"B`@("`@("`@("`@(&9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PH@
M("`@("`@("`@("`@("`@:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD7WTI('L*("`@("`@("`@("`@("`@("`@("`D9FEL92`]("1?.PH@
M("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!E;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<
M6B]I*2!["B`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H
M)#$L("0R*3L*("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@96QS:68@*&TA7B]L;V%D97(O6UXO
M72LO*"XJ6UY#8UTI7%HA*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&UY
M("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@96QS:68@*"UF("(D9&ER
M+R0Q(BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE
M*2`]("@B)&1I<B\D,2(L("0Q*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M;&%S=#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&YE>'0@=6YL97-S(&1E9FEN
M960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*("`@("`@("`@
M("`@;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB
M7V5X=%Q%)"\["B`@("`@("`@("`@(&]U=',H(&IO:6X@(B(L"B`@("`@("`@
M("`@("`@("!Q<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA
M;65](#H@)&9I;&4L"B`@("`@("`@("`@("`@("!Q<2@B+BXN*0H@("`@("`@
M("`@("`I.PH*("`@("`@("`@("`@;7D@)&-O;G1E;G0["B`@("`@("`@("`@
M(&EF("AR968H)&9I;&4I*2!["B`@("`@("`@("`@("`@("`D8V]N=&5N="`]
M("1F:6QE+3Y[8G5F?3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E
M('L*("`@("`@("`@("`@("`@(&]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D
M:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*("`@("`@("`@("`@("`@(&)I
M;FUO9&4H1DE,12D["B`@("`@("`@("`@("`@("`D8V]N=&5N="`](#Q&24Q%
M/CL*("`@("`@("`@("`@("`@(&-L;W-E($9)3$4["@H@("`@("`@("`@("`@
M("`@4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N
M="P@)&9I;&4I"B`@("`@("`@("`@("`@("`@("`@:68@(21%3E9[4$%27U9%
M4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PH*("`@
M("`@("`@("`@("`@(",@1&\@;F]T(&QE="!84TQO861E<B!P:6-K('5P(&%U
M=&\O*B!F<F]M(&5N=FER;VYM96YT"B`@("`@("`@("`@("`@("`D8V]N=&5N
M="`]?B!S+V=O=&\@*W)E=')Y("MU;FQE<W,@*RXJ+V=O=&\@<F5T<GD[+PH@
M("`@("`@("`@("`@("`@("`@(&EF(&QC*"1N86UE*2!E<2!L8R@B6%-,;V%D
M97(N<&TB*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@;W5T<RAQ<2A7
M<FET=&5N(&%S("(D;F%M92(I*3L*("`@("`@("`@("`@)&9H+3YP<FEN="@B
M1DE,12(I.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG
M=&@H)&YA;64I("L@.2DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'-P<FEN
M=&8H"B`@("`@("`@("`@("`@("`B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ
M8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64*("`@("`@("`@("`@*2D[
M"B`@("`@("`@("`@("1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N
M=&5N="DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN="@D8V]N=&5N="D["B`@
M("`@("`@?0H@("`@?0H@("`@(R!]?7T*"B`@("`C($YO=R!W<FET92!O=70@
M=&AE(%!!4B!A;F0@;6%G:6,@<W1R:6YG<R![>WL*("`@("1Z:7`M/G=R:71E
M5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*"B`@("`D8V%C:&5?;F%M92`]
M('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["B`@("!I9B`H(21C86-H95]N
M86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*("`@("`@
M("!M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S
M=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@("`@
M("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U
M+3YN97<@?3L*"B`@("`@("`@(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@1&EG
M97-T.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@(&UY("1S:&%?=F5R<VEO
M;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@
M("`@(&EF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO
M;B!E<2`G-2XS.2<I('L*("`@("`@("`@("`@)&-T>"T^861D9FEL92@D;W5T
M+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@
M("`@("`@("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI
M('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@
M("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@("`@("`@(&-L;W-E
M*"1F:"D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1C86-H
M95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*("`@
M('T*("`@("1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A
M8VAE7VYA;64I.PH@("`@)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*("`@("1F
M:"T^<')I;G0H)&-A8VAE7VYA;64I.PH@("`@)&9H+3YP<FEN="AP86-K*"=.
M)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B`@("`D9F@M/G!R
M:6YT*")<;E!!4BYP;5QN(BD["B`@("`D9F@M/F-L;W-E.PH@("`@8VAM;V0@
M,#<U-2P@)&]U=#L*("`@(",@?7U]"@H@("`@97AI=#L*?0HC('U]?0H*(R!0
M<F5P87)E("1P<F]G;F%M92!I;G1O(%!!4B!F:6QE(&-A8VAE('M[>PI["B`@
M("!L87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["@H@("`@7V9I>%]P
M<F]G;F%M92@I.PH*("`@(",@3F]W(&QO860@=&AE(%!!4B!F:6QE(&%N9"!P
M=70@:70@:6YT;R!005(Z.DQI8D-A8VAE('M[>PH@("`@<F5Q=6ER92!005([
M"B`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H*("`@('L*
M("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D
M7D\@;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I<F4@1FEL93HZ1FEN9#L*
M("`@("`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@('T*("`@(&UY("1Z
M:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*("`@(&UY("1F:"`]($E/.CI&:6QE
M+3YN97<["B`@("`D9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D
M:64@(B0A.B`D0"(["B`@("`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H
M+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@
M(B0A.B`D0"(["@H@("`@<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*("`@
M("1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PH*("`@("1Q=6EE
M="`]("$D14Y6>U!!4E]$14)51WT["B`@("!O=71S*'%Q*%PD14Y6>U!!4E]4
M14U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*"B`@("!I9B`H9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN
M="$*("`@("`@("!F;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S
M("D@>PH@("`@("`@("`@("!N97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y
M.PH@("`@("`@("`@("!M>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE
M3F%M93L*("`@("`@("`@("`@;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^
M(&U["B`@("`@("`@("`@("`@("!>"B`@("`@("`@("`@("`@("`O/W-H;&EB
M+PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]
M+RD_"B`@("`@("`@("`@("`@("`H/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA
M;65]+RD_"B`@("`@("`@("`@("`@("`H6UXO72LI"B`@("`@("`@("`@("`@
M("`D"B`@("`@("`@("`@('UX.PH@("`@("`@("`@("!M>2`D97AT<F%C=%]N
M86UE(#T@)#$["B`@("`@("`@("`@(&UY("1D97-T7VYA;64@/2!&:6QE.CI3
M<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*
M("`@("`@("`@("`@:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M
M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*("`@("`@("`@("`@("`@(&]U
M=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D
M>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("!O=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB
M97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B`@("`@("`@("`@("`@("`D
M;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["B`@("`@
M("`@("`@("`@("!C:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@
M(FAP=7@B.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H@("`@(R!]
M?7T*?0HC('U]?0H*(R!)9B!T:&5R92=S(&YO(&UA:6XN<&P@=&\@<G5N+"!S
M:&]W('5S86=E('M[>PIU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M
M97TI('L*("`@(&1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@
M6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A
M<B!=(%L@<')O9W)A;2YP;"!="B`@("`@("`D,"!;("U"?"UB(%T@6RU/;W5T
M9FEL95T@<W)C+G!A<@HN"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O
M9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0HC('U]?0H*<W5B($-R96%T
M95!A=&@@>PH@("`@;7D@*"1N86UE*2`]($!?.PH@("`@"B`@("!R97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PH@("`@;7D@*"1B87-E;F%M92P@)'!A=&@L("1E
M>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ
M)RDI.PH@("`@"B`@("!R97%U:7)E($9I;&4Z.E!A=&@["B`@("`*("`@($9I
M;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M
M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*"G-U8B!R97%U:7)E7VUO9'5L97,@
M>PH@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/
M(&YE("=-4U=I;C,R)SL*"B`@("!R97%U:7)E(&QI8CL*("`@(')E<75I<F4@
M1'EN84QO861E<CL*("`@(')E<75I<F4@:6YT96=E<CL*("`@(')E<75I<F4@
M<W1R:6-T.PH@("`@<F5Q=6ER92!W87)N:6YG<SL*("`@(')E<75I<F4@=F%R
M<SL*("`@(')E<75I<F4@0V%R<#L*("`@(')E<75I<F4@0V%R<#HZ2&5A=GD[
M"B`@("!R97%U:7)E($5R<FYO.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A
M=GD["B`@("!R97%U:7)E($5X<&]R=&5R.PH@("`@<F5Q=6ER92!&8VYT;#L*
M("`@(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E<75I<F4@1FEL93HZ4W!E
M8SL*("`@(')E<75I<F4@6%-,;V%D97(["B`@("!R97%U:7)E($-O;F9I9SL*
M("`@(')E<75I<F4@24\Z.DAA;F1L93L*("`@(')E<75I<F4@24\Z.D9I;&4[
M"B`@("!R97%U:7)E($-O;7!R97-S.CI:;&EB.PH@("`@<F5Q=6ER92!!<F-H
M:79E.CI::7`["B`@("!R97%U:7)E(%!!4CL*("`@(')E<75I<F4@4$%2.CI(
M96%V>3L*("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@<F5Q=6ER92!005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`["B`@("!R97%U:7)E(&%T=')I8G5T97,["B`@
M("!E=F%L('L@<F5Q=6ER92!#=V0@?3L*("`@(&5V86P@>R!R97%U:7)E(%=I
M;C,R('T["B`@("!E=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*("`@
M(&5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PH@("`@
M979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*("`@
M(&5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA
M<B!].PI]"@HC(%1H92!#('9E<G-I;VX@;V8@=&AI<R!C;V1E(&%P<&5A<G,@
M:6X@;7EL9'(O;6MT;7!D:7(N8PHC(%1H:7,@8V]D92!A;'-O(&QI=F5S(&EN
M(%!!4CHZ4V5T=7!496UP(&%S('-E=%]P87)?=&5M<%]E;G8A"G-U8B!?<V5T
M7W!A<E]T96UP('L*("`@(&EF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N
M9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*("`@("`@("`D<&%R7W1E
M;7`@/2`D,3L*("`@("`@("!R971U<FX["B`@("!]"@H@("`@9F]R96%C:"!M
M>2`D<&%T:"`H"B`@("`@("`@*&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$
M25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"B`@("`@("`@<7<H($,Z
M7%Q414U0("]T;7`@+B`I"B`@("`I('L*("`@("`@("!N97AT('5N;&5S<R!D
M969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["B`@("`@
M("`@;7D@)'5S97)N86UE.PH@("`@("`@(&UY("1P=W5I9#L*("`@("`@("`C
M(&1O97,@;F]T('=O<FL@979E<GEW:&5R93H*("`@("`@("!E=F%L('LH)'!W
M=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["@H@("`@("`@
M(&EF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B`@("`@("`@
M("`@("1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PH@("`@("`@('T*
M("`@("`@("!E;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*("`@("`@("`@("`@
M)'5S97)N86UE(#T@)'!W=6ED.PH@("`@("`@('T*("`@("`@("!E;'-E('L*
M("`@("`@("`@("`@)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.
M5GM54T52?2!\?"`G4UE35$5-)SL*("`@("`@("!]"B`@("`@("`@)'5S97)N
M86UE(#U^(',O7%<O7R]G.PH*("`@("`@("!M>2`D<W1M<&1I<B`]("(D<&%T
M:"1#;VYF:6=[7V1E;&EM?7!A<BTD=7-E<FYA;64B.PH@("`@("`@(&UK9&ER
M("1S=&UP9&ER+"`P-S4U.PH@("`@("`@(&EF("@A)$5.5GM005)?0TQ%04Y]
M(&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PH@("`@
M("`@("`@("!O<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*("`@("`@
M("`@("`@<V5E:R`D9F@L("TQ."P@,CL*("`@("`@("`@("`@<WES<F5A9"`D
M9F@L(&UY("1B=68L(#8["B`@("`@("`@("`@(&EF("@D8G5F(&5Q(")<,$-!
M0TA%(BD@>PH@("`@("`@("`@("`@("`@<V5E:R`D9F@L("TU."P@,CL*("`@
M("`@("`@("`@("`@('-Y<W)E860@)&9H+"`D8G5F+"`T,3L*("`@("`@("`@
M("`@("`@("1B=68@/7X@<R]<,"\O9SL*("`@("`@("`@("`@("`@("1S=&UP
M9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(&UY
M("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI3
M2$$M/FYE=R@Q*2!]"B`@("`@("`@("`@("`@("`@("`@?'P@979A;"![(')E
M<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@
M("`@("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[
M($1I9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@("`@("`@("`C(%=O<FMA
M<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@
M("`@("`@("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S
M=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@("`@("`@("`@("`@(&EF("@D
M<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS
M.2<I('L*("`@("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1P<F]G
M;F%M92P@(F(B*2!I9B`H)&-T>"D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&-T
M>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("`@("`@
M("`@("`@("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@("`@
M("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1S=&UP9&ER("X]("(D
M0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG
M97-T(#H@)&UT:6UE("D["B`@("`@("`@("`@('T*("`@("`@("`@("`@8VQO
M<V4H)&9H*3L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@
M("1%3E9[4$%27T-,14%.?2`](#$["B`@("`@("`@("`@("1S=&UP9&ER("X]
M("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*("`@("`@("!]"@H@("`@("`@
M("1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["B`@("`@("`@;6MD:7(@)'-T
M;7!D:7(L(#`W-34["B`@("`@("`@;&%S=#L*("`@('T*"B`@("`D<&%R7W1E
M;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@
M/7X@+R@N*RDO.PI]"@IS=6(@7W1E;7!F:6QE('L*("`@(&UY("@D97AT+"`D
M8W)C*2`]($!?.PH@("`@;7D@*"1F:"P@)&9I;&5N86UE*3L*"B`@("`D9FEL
M96YA;64@/2`B)'!A<E]T96UP+R1C<F,D97AT(CL*"B`@("!I9B`H)$5.5GM0
M05)?0TQ%04Y]*2!["B`@("`@("`@=6YL:6YK("1F:6QE;F%M92!I9B`M92`D
M9FEL96YA;64["B`@("`@("`@<'5S:"!`=&UP9FEL92P@)&9I;&5N86UE.PH@
M("`@?0H@("`@96QS92!["B`@("`@("`@<F5T=7)N("AU;F1E9BP@)&9I;&5N
M86UE*2!I9B`H+7(@)&9I;&5N86UE*3L*("`@('T*"B`@("!O<&5N("1F:"P@
M)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@8FEN;6]D92@D9F@I.PH@
M("`@<F5T=7)N*"1F:"P@)&9I;&5N86UE*3L*?0H*(R!S86UE(&-O9&4@;&EV
M97,@:6X@4$%2.CI3971U<%!R;V=N86UE.CIS971?<')O9VYA;64*<W5B(%]S
M971?<')O9VYA;64@>PH@("`@:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!
M345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B`@("`@
M("`@)'!R;V=N86UE(#T@)#$["B`@("!]"@H@("`@)'!R;V=N86UE('Q\/2`D
M,#L*"B`@("!I9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M
M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*("`@("`@("`D<')O9VYA;64@
M/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG
M>U]D96QI;7TI("L@,2D["B`@("!]"@H@("`@:68@*"$D14Y6>U!!4E]04D]'
M3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X]
M(#`I('L*("`@("`@("!I9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE
M*2!["B`@("`@("`@("`@(')E='5R;B!I9B`M<R`D9F@["B`@("`@("`@?0H@
M("`@("`@(&EF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*("`@
M("`@("`@("`@)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["B`@("`@("`@
M("`@(')E='5R;CL*("`@("`@("!]"B`@("!]"@H@("`@9F]R96%C:"!M>2`D
M9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(
M?2D@>PH@("`@("`@(&YE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N
M9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PH@("`@("`@("1D:7(@/7X@<R]<
M421#;VYF:6=[7V1E;&EM?5Q%)"\O.PH@("`@("`@("@H)'!R;V=N86UE(#T@
M(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL
M(&QA<W0I"B`@("`@("`@("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B`@("`@("`@*"@D<')O9VYA;64@
M/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0H@("`@
M("`@("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92([
M"B`@("!]"GT*"G-U8B!?9FEX7W!R;V=N86UE('L*("`@("0P(#T@)'!R;V=N
M86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["B`@("!I9B`H:6YD97@H)'!R
M;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PH@("`@("`@("1P<F]G
M;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*("`@('T*"B`@
M("`C(%A86"`M(&AA8VL@=&\@;6%K92!05T0@=V]R:PH@("`@;7D@)'!W9"`]
M("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"B`@("`@
M("`@("`@("`@("`Z("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS
M,CHZ1V5T0W=D*"D@.B!@<'=D8"D["B`@("!C:&]M<"@D<'=D*3L*("`@("1P
M<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P
M=V0D0V]N9FEG>U]D96QI;7TO.PH*("`@("1%3E9[4$%27U!23T=.04U%?2`]
M("1P<F]G;F%M93L*?0H*<W5B(%]P87)?:6YI=%]E;G8@>PH@("`@:68@*"`D
M14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PH@("`@("`@(')E='5R
M;CL*("`@('T@96QS92!["B`@("`@("`@)$5.5GM005)?24Y)5$E!3$E:141]
M(#T@,CL*("`@('T*"B`@("!F;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@
M1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*("`@("`@
M("!D96QE=&4@)$5.5GLG4$%27R<N)%]].PH@("`@?0H@("`@9F]R("AQ=R\@
M5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PH@("`@("`@("1%3E9[)U!!
M4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%
M3E9[)U!!4E]'3$]"04Q?)RXD7WT["B`@("!]"@H@("`@;7D@)'!A<E]C;&5A
M;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["@H@("`@
M:68@*"1%3E9[4$%27U1%35!]*2!["B`@("`@("`@9&5L971E("1%3E9[4$%2
M7T-,14%.?3L*("`@('T*("`@(&5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,
M3T)!3%]#3$5!3GTI('L*("`@("`@("!M>2`D=F%L=64@/2!S=6)S='(H)'!A
M<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PH@("`@("`@("1%3E9[
M4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K
M*2\["B`@("!]"GT*"G-U8B!O=71S('L*("`@(')E='5R;B!I9B`D<75I970[
M"B`@("!I9B`H)&QO9V9H*2!["B`@("`@("`@<')I;G0@)&QO9V9H(")`7UQN
M(CL*("`@('T*("`@(&5L<V4@>PH@("`@("`@('!R:6YT(")`7UQN(CL*("`@
M('T*?0H*<W5B(&EN:71?:6YC('L*("`@(')E<75I<F4@0V]N9FEG.PH@("`@
M<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[
M)%]]+"!Q=R@*("`@("`@("!A<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R
M8VAE>'`@<VET96QI8F5X<`H@("`@("`@('9E;F1O<F%R8VAE>'`@=F5N9&]R
M;&EB97AP"B`@("`I.PI]"@HC(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,*
M(R!4:&4@;6%I;B!P86-K86=E(&9O<B!S8W)I<'0@97AE8W5T:6]N"@IP86-K
M86=E(&UA:6X["@IR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ
M9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["@ID:64@<7$H<&%R
M+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S
M=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"B`@("!U;FQE<W,@+64@)'!R;V=N
M86UE.PH*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO
M7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["@I].PH*)#HZ
M7U]%4E)/4B`]("1`(&EF("1`.PI]"@I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ
M7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T52
M4D]2(&EF("0Z.E]?15)23U(["@HQ.PH*(VQI;F4@,3`Q,@H*7U]%3D1?7PH`
M)$9R965"4T0Z('-R8R]L:6(O8W-U+V%M9#8T+V-R=&XN4RQV(#$N-BXS,"XQ
M+C(N,2`R,#`Y+S$P+S(U(#`Q.C$P.C(Y(&ME;G-M:71H($5X<"`D```!&___
M-``0`'140`````````````````#8MU```````/____\`````@%5```````#I
M6P```````!0``````````7I2``%X$`$##`<(D`$``"0````<````@!]``)P`
M````00X0A@)##09"C0-+@P6,!``````````4````1````"`@0``X`````$0.
M$``````4````7````&`@0``B```````````````4````=````)`@0``T````
M```````````L````C````-`@0`#P%0```$(.$$8.&$(.($$.*(8%C`2-`XX"
M1`XP1PZX!(,&```D````O````,`V0`#9`````$J/`HP%7@Y`C@.-!(8&@P<`
M````````'````.0```"@-T``3P````!!#A!!#AB#`X8"1PXP```4````!`$`
M`/`W0``5`````$0.(``````4````'`$``!`X0`!-`````$0.$``````4````
M-`$``&`X0``>`````$0.$``````4````3`$``(`X0`#'`````%$.$(,"```<
M````9`$``%`Y0`!"`0```$J#!HP$60ZP`8X"C0.&!1P```"$`0``H#I``$\`
M````00X0@P)'#I`!````````-````*0!``#P.D``!0(```!"#A!$#AB.`X\"
M10X@0@XH00XPA@:,!8T$1`XX1`Y0@P<````````T````W`$````]0``-`0``
M`$(.$$(.&(X#CP)%#B!"#BB,!8T$1PXP00XX1`YP@P>&!@```````!0````4
M`@``$#Y``+X!````1`Y``````!0````L`@``T#]``"(`````1`X0`````!P`
M``!$`@```$!``.(`````00X000X8@P.&`D<.(```%````&0"``#P0$``;0``
M``!.#B"&`H,#'````'P"``!@04``\`$```!!#A!$#C"#`@`````````T````
MG`(``%!#0`"L`0```$(.$$(.&$(.($(.*(P%C02.`X\"20XP00XX@P>&!DH.
MX`D``````#0```#4`@```$5``"@)````0@X00@X80@X@0@XH00XP00XX1PZP
M@P*#!X8&C`6-!(X#CP(`````'`````P#```P3D``R0````!6#L`0C`*&`X,$
M```````4````+`,```!/0``%```````````````<````1`,``!!/0`#(`@``
M`$(.$$\.&$$.((,$A@.,`A0```!D`P``X%%``!0``````````````!0```!\
M`P```%)``"<`````1`X0```````````8``````````%Z4@`!>!`!`PP'")`!
M````````%````"`````P4D``)0````!(#A"#`@```0`````````!````````
M``$`````````'0(````````!`````````"<"`````````0`````````U`@``
M``````$`````````0@(````````/`````````)(#````````#`````````"@
M&T````````T`````````6%)````````$`````````/@!0```````!0``````
M``#H#D````````8`````````*`5````````*`````````-8$````````"P``
M```````8`````````!4````````````````````#`````````.BW4```````
M`@````````"(!0```````!0`````````!P`````````7`````````!@60```
M````!P````````"P%$````````@`````````:`$````````)`````````!@`
M````````_O__;P````"0%$```````/___V\``````0````````#P__]O````
M`+X30```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````__________\``````````/__________````````
M`````````````."U4````````````````````````````,H;0```````VAM`
M``````#J&T```````/H;0```````"AQ````````:'$```````"H<0```````
M.AQ```````!*'$```````%H<0```````:AQ```````!Z'$```````(H<0```
M````FAQ```````"J'$```````+H<0```````RAQ```````#:'$```````.H<
M0```````^AQ````````*'4```````!H=0```````*AU````````Z'4``````
M`$H=0```````6AU```````!J'4```````'H=0```````BAU```````":'4``
M`````*H=0```````NAU```````#*'4```````-H=0```````ZAU```````#Z
M'4````````H>0```````&AY````````J'D```````#H>0```````2AY`````
M``!:'D```````&H>0```````>AY```````"*'D```````)H>0```````JAY`
M``````"Z'D```````,H>0```````VAY```````#J'D```````/H>0```````
M"A]````````:'T```````"H?0```````.A]```````!*'T```````%H?0```
M````:A]````````````````````D1G)E94)31#H@<W)C+VQI8B]C<W4O8V]M
M;6]N+V-R=&)R86YD+F,L=B`Q+C8N,BXQ+C(N,2`R,#`Y+S$P+S(U(#`Q.C$P
M.C(Y(&ME;G-M:71H($5X<"`D`"1&<F5E0E-$.B!S<F,O;&EB+V-S=2]A;60V
M-"]C<G0Q+F,L=B`Q+C$U+C$P+C$N,BXQ(#(P,#DO,3`O,C4@,#$Z,3`Z,CD@
M:V5N<VUI=&@@17AP("0`1T-#.B`H1TY5*2`T+C(N,2`R,#`W,#<Q.2`@6T9R
M965"4T1=``!'0T,Z("A'3E4I(#0N,BXQ(#(P,#<P-S$Y("!;1G)E94)31%T`
M`$=#0SH@*$=.52D@-"XR+C$@,C`P-S`W,3D@(%M&<F5E0E-$70``1T-#.B`H
M1TY5*2`T+C(N,2`R,#`W,#<Q.2`@6T9R965"4T1=``!'0T,Z("A'3E4I(#0N
M,BXQ(#(P,#<P-S$Y("!;1G)E94)31%T``"YS:'-T<G1A8@`N:6YT97)P`"YN
M;W1E+D%"22UT86<`+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO
M;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT
M97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N9&%T80`N96A?9G)A
M;64`+F1Y;F%M:6,`+F-T;W)S`"YD=&]R<P`N:F-R`"YG;W0`+F)S<P`N8V]M
M;65N=```````````````````````````````````````````````````````
M```````````````````````````````````````+`````0````(`````````
MR`%```````#(`0```````!4````````````````````!````````````````
M````$P````<````"`````````.`!0```````X`$````````8````````````
M````````!````````````````````"$````%`````@````````#X`4``````
M`/@!````````+`,````````$``````````@`````````!``````````G````
M"P````(`````````*`5````````H!0```````,`)````````!0````$````(
M`````````!@`````````+P````,````"`````````.@.0```````Z`X`````
M``#6!````````````````````0```````````````````#<```#___]O`@``
M``````"^$T```````+X3````````T``````````$``````````(`````````
M`@````````!$````_O__;P(`````````D!1```````"0%````````"``````
M````!0````$````(````````````````````4P````0````"`````````+`4
M0```````L!0```````!H`0````````0`````````"``````````8````````
M`%T````$`````@`````````8%D```````!@6````````B`4````````$````
M"P````@`````````&`````````!G`````0````8`````````H!M```````"@
M&P```````!,````````````````````$````````````````````8@````$`
M```&`````````+0;0```````M!L```````#``P``````````````````!```
M```````0`````````&T````!````!@````````"`'T```````(`?````````
MV#(``````````````````!````````````````````!S`````0````8`````
M````6%)```````!84@````````X````````````````````$````````````
M````````>0````$````"`````````(!20```````@%(```````!?7P``````
M````````````(````````````````````($````!`````@````````#@L4``
M`````."Q````````"`````````````````````0```````````````````"/
M`````0````,`````````Z+%0``````#HL0```````#``````````````````
M```(````````````````````E0````$````"`````````!BR4```````&+(`
M``````#(`P``````````````````"````````````````````)\````&````
M`P````````#@M5```````."U````````X`$````````%``````````@`````
M````$`````````"H`````0````,`````````P+=0``````#`MP```````!``
M```````````````````(````````````````````KP````$````#````````
M`-"W4```````T+<````````0````````````````````"```````````````
M`````+8````!`````P````````#@MU```````."W````````"```````````
M``````````@```````````````````"[`````0````,`````````Z+=0````
M``#HMP```````/`!```````````````````(``````````@`````````P```
M``@````#`````````."Y4```````X+D````````(!0``````````````````
M(````````````````````,4````!`````````````````````````."Y````
M````;0$```````````````````$````````````````````!`````P``````
M``````````````````!-NP```````,X````````````````````!````````
)````````````
